apiAttachAvailable = u'API tillg\xe4ngligt'
apiAttachNotAvailable = u'Inte tillg\xe4ngligt'
apiAttachPendingAuthorization = u'Godk\xe4nnande avvaktas'
apiAttachRefused = u'Nekades'
apiAttachSuccess = u'Det lyckades'
apiAttachUnknown = u'Ok\xe4nd'
budDeletedFriend = u'Borttagen fr\xe5n kontaktlistan'
budFriend = u'V\xe4n'
budNeverBeenFriend = u'Aldrig varit i kontaktlistan'
budPendingAuthorization = u'Godk\xe4nnande avvaktas'
budUnknown = u'Ok\xe4nd'
cfrBlockedByRecipient = u'Samtalet blockerades av mottagaren'
cfrMiscError = u'Div fel'
cfrNoCommonCodec = u'Gemensam codec saknas'
cfrNoProxyFound = u'Mellanserver finns inte'
cfrNotAuthorizedByRecipient = u'Aktuell anv\xe4ndare inte godk\xe4nd av mottagaren'
cfrRecipientNotFriend = u'Mottagaren ej en v\xe4n'
cfrRemoteDeviceError = u'Det har uppst\xe5tt problem med motpartens ljudenhet'
cfrSessionTerminated = u'Sessionen avslutad'
cfrSoundIOError = u'I/O-fel p\xe5 ljudet'
cfrSoundRecordingError = u'Ljudinspelningsfel'
cfrUnknown = u'Ok\xe4nd'
cfrUserDoesNotExist = u'Anv\xe4ndaren/telefonnumret finns inte'
cfrUserIsOffline = u'Anv\xe4ndaren \xe4r offline'
chsAllCalls = u'Legacy-dialog'
chsDialog = u'Dialog'
chsIncomingCalls = u'Kr\xe4ver multi-godk\xe4nnande'
chsLegacyDialog = u'Legacy-dialog'
chsMissedCalls = u'Dialog'
chsMultiNeedAccept = u'Kr\xe4ver multi-godk\xe4nnande'
chsMultiSubscribed = u'Multi-abonnerade'
chsOutgoingCalls = u'Multi-abonnerade'
chsUnknown = u'Ok\xe4nd'
chsUnsubscribed = u'Avabonnerad'
clsBusy = u'Upptaget'
clsCancelled = u'Avbruten'
clsEarlyMedia = u'Spelar Early Media'
clsFailed = u'Samtalet kunde inte kopplas'
clsFinished = u'Avslutat'
clsInProgress = u'P\xe5g\xe5ende samtal'
clsLocalHold = u'Lokalt parkerat samtal'
clsMissed = u'missat samtal'
clsOnHold = u'Parkerad'
clsRefused = u'Nekades'
clsRemoteHold = u'Fj\xe4rrparkerat samtal'
clsRinging = u'pratat'
clsRouting = u'Routar'
clsTransferred = u'Ok\xe4nd'
clsTransferring = u'Ok\xe4nd'
clsUnknown = u'Ok\xe4nd'
clsUnplaced = u'Inte uppringt'
clsVoicemailBufferingGreeting = u'Buffrar h\xe4lsningen'
clsVoicemailCancelled = u'R\xf6stmeddelandet avbr\xf6ts'
clsVoicemailFailed = u'R\xf6stmeddelandet misslyckades'
clsVoicemailPlayingGreeting = u'Spelar h\xe4lsningen'
clsVoicemailRecording = u'Spelar in r\xf6stmeddelande'
clsVoicemailSent = u'R\xf6stmeddelandet skickades'
clsVoicemailUploading = u'Laddar upp r\xf6stmeddelande'
cltIncomingP2P = u'Inkommande P2P-samtal'
cltIncomingPSTN = u'Inkommande telefonsamtal'
cltOutgoingP2P = u'Utg\xe5ende P2P-samtal'
cltOutgoingPSTN = u'Utg\xe5ende telefonsamtal'
cltUnknown = u'Ok\xe4nd'
cmeAddedMembers = u'Medlemmar lades till'
cmeCreatedChatWith = u'Startade chatt med'
cmeEmoted = u'Ok\xe4nd'
cmeLeft = u'L\xe4mnade'
cmeSaid = u'Redan sagt'
cmeSawMembers = u'S\xe5g medlemmar'
cmeSetTopic = u'Ange \xe4mne'
cmeUnknown = u'Ok\xe4nd'
cmsRead = u'L\xe4stes'
cmsReceived = u'Togs emot'
cmsSending = u'S\xe4nder...'
cmsSent = u'Skickades'
cmsUnknown = u'Ok\xe4nd'
conConnecting = u'Ansluter...'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'Pauserar'
conUnknown = u'Ok\xe4nd'
cusAway = u'Tillf\xe4lligt borta'
cusDoNotDisturb = u'St\xf6r ej'
cusInvisible = u'Osynlig'
cusLoggedOut = u'Offline'
cusNotAvailable = u'Inte tillg\xe4ngligt'
cusOffline = u'Offline'
cusOnline = u'Online'
cusSkypeMe = u'Skype Me'
cusUnknown = u'Ok\xe4nd'
cvsBothEnabled = u'Skickar och tar emot video'
cvsNone = u'Ingen video'
cvsReceiveEnabled = u'Tar emot video'
cvsSendEnabled = u'Skickar video'
cvsUnknown = u''
grpAllFriends = u'Alla kontakter'
grpAllUsers = u'Alla anv\xe4ndare'
grpCustomGroup = u'S\xe4rskild'
grpOnlineFriends = u'Online-v\xe4nner'
grpPendingAuthorizationFriends = u'Godk\xe4nnande avvaktas'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Nyligen kontaktade anv\xe4ndare'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-kontakter'
grpSkypeOutFriends = u'SkypeOut-kontakter'
grpUngroupedFriends = u'Icke grupperade kontakter'
grpUnknown = u'Ok\xe4nd'
grpUsersAuthorizedByMe = u'Godk\xe4nda av mig'
grpUsersBlockedByMe = u'Blockerade av mig'
grpUsersWaitingMyAuthorization = u'Avvaktar mitt godk\xe4nnande'
leaAddDeclined = u'Till\xe4gg nekades'
leaAddedNotAuthorized = u'Den som l\xe4ggs till m\xe5ste vara godk\xe4nd'
leaAdderNotFriend = u'Den som l\xe4gger till m\xe5ste vara en v\xe4n'
leaUnknown = u'Ok\xe4nd'
leaUnsubscribe = u'Avabonnerad'
leaUserIncapable = u'Anv\xe4ndaren kan inte'
leaUserNotFound = u'Anv\xe4ndaren finns inte'
olsAway = u'Tillf\xe4lligt borta'
olsDoNotDisturb = u'St\xf6r ej'
olsNotAvailable = u'Inte tillg\xe4ngligt'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Ok\xe4nd'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Kvinna'
usexMale = u'Man'
usexUnknown = u'Ok\xe4nd'
vmrConnectError = u'Anslutningsfel'
vmrFileReadError = u'Fill\xe4sningsfel'
vmrFileWriteError = u'Filskrivningsfel'
vmrMiscError = u'Div fel'
vmrNoError = u'Inget fel'
vmrNoPrivilege = u'Voicemail-beh\xf6righet saknas'
vmrNoVoicemail = u'R\xf6stmeddelande saknas'
vmrPlaybackError = u'Uppspelningsfel'
vmrRecordingError = u'Inspelningsfel'
vmrUnknown = u'Ok\xe4nd'
vmsBlank = u'Tomt'
vmsBuffering = u'Buffrar'
vmsDeleting = u'Tar bort'
vmsDownloading = u'Laddar ner'
vmsFailed = u'Misslyckades'
vmsNotDownloaded = u'Inte nerladdat'
vmsPlayed = u'Uppspelat'
vmsPlaying = u'Spelar upp'
vmsRecorded = u'Inspelat'
vmsRecording = u'Spelar in r\xf6stmeddelande'
vmsUnknown = u'Ok\xe4nd'
vmsUnplayed = u'Inte uppspelat'
vmsUploaded = u'Uppladdat'
vmsUploading = u'Laddar upp'
vmtCustomGreeting = u'S\xe4rskild h\xe4lsning'
vmtDefaultGreeting = u'Standardh\xe4lsning'
vmtIncoming = u'Nytt r\xf6stmeddelande'
vmtOutgoing = u'Utg\xe5ende'
vmtUnknown = u'Ok\xe4nd'
vssAvailable = u'Tillg\xe4ngligt'
vssNotAvailable = u'Inte tillg\xe4ngligt'
vssPaused = u'Pausat'
vssRejected = u'Nekades'
vssRunning = u'P\xe5g\xe5r'
vssStarting = u'Startar'
vssStopping = u'Stannar'
vssUnknown = u'Ok\xe4nd'



apiAttachAvailable = u'API saatavilla'
apiAttachNotAvailable = u'Ei saatavilla'
apiAttachPendingAuthorization = u'Odottaa valtuutusta'
apiAttachRefused = u'Ev\xe4tty'
apiAttachSuccess = u'Onnistui'
apiAttachUnknown = u'Tuntematon'
budDeletedFriend = u'Poistettu yst\xe4v\xe4listasta'
budFriend = u'Yst\xe4v\xe4'
budNeverBeenFriend = u'Ei aiempia yst\xe4v\xe4listauksia'
budPendingAuthorization = u'Odottaa valtuutusta'
budUnknown = u'Tuntematon'
cfrBlockedByRecipient = u'Vastaanottaja esti soiton'
cfrMiscError = u'Sekal virhe'
cfrNoCommonCodec = u'Ei yleinen koodekki'
cfrNoProxyFound = u'Proxy ei l\xf6ytynyt'
cfrNotAuthorizedByRecipient = u'K\xe4ytt\xe4j\xe4ll\xe4 ei ole vastaanottajan hyv\xe4ksynt\xe4\xe4'
cfrRecipientNotFriend = u'Vastaanottaja ei ole yst\xe4v\xe4'
cfrRemoteDeviceError = u'Ongelma et\xe4-\xe4\xe4nilaitteessa'
cfrSessionTerminated = u'Istunto p\xe4\xe4ttyi'
cfrSoundIOError = u'\xc4\xe4nen I/O-virhe'
cfrSoundRecordingError = u'\xc4\xe4nentallennusvirhe'
cfrUnknown = u'Tuntematon'
cfrUserDoesNotExist = u'Tuntematon k\xe4ytt\xe4j\xe4/puhelinnumero'
cfrUserIsOffline = u'H\xe4n on Offline-tilassa'
chsAllCalls = u'Vanha dialogi'
chsDialog = u'Dialogi'
chsIncomingCalls = u'Multi-chat odottaa hyv\xe4ksynt\xf6j\xe4'
chsLegacyDialog = u'Vanha dialogi'
chsMissedCalls = u'Dialogi'
chsMultiNeedAccept = u'Multi-chat odottaa hyv\xe4ksynt\xf6j\xe4'
chsMultiSubscribed = u'Multi tilattu'
chsOutgoingCalls = u'Multi tilattu'
chsUnknown = u'Tuntematon'
chsUnsubscribed = u'Ei tilaaja'
clsBusy = u'Varattu'
clsCancelled = u'Peruutettu'
clsEarlyMedia = u'K\xe4sittelee ennakkomediaa (Early Media)'
clsFailed = u'Ik\xe4v\xe4 kyll\xe4, puhelu ep\xe4onnistui!'
clsFinished = u'Valmis'
clsInProgress = u'Puhelu k\xe4ynniss\xe4'
clsLocalHold = u'Paikalliseti pidossa'
clsMissed = u'vastaamaton puhelu'
clsOnHold = u'Pidossa'
clsRefused = u'Ev\xe4tty'
clsRemoteHold = u'Et\xe4pidossa'
clsRinging = u'soittamassa'
clsRouting = u'Reitittt\xe4\xe4'
clsTransferred = u'Tuntematon'
clsTransferring = u'Tuntematon'
clsUnknown = u'Tuntematon'
clsUnplaced = u'Ei koskaan valittu'
clsVoicemailBufferingGreeting = u'Puskuroi tervehdyst\xe4'
clsVoicemailCancelled = u'Puheposti on peruutettu'
clsVoicemailFailed = u'Puheposti ep\xe4onnistui'
clsVoicemailPlayingGreeting = u'Toistaa tervehdyst\xe4'
clsVoicemailRecording = u'Puhepostin \xe4\xe4nitys'
clsVoicemailSent = u'Puheposti on l\xe4hetetty'
clsVoicemailUploading = u'Lataa puhepostia'
cltIncomingP2P = u'Saapuva vertaissoitto'
cltIncomingPSTN = u'Saapuva puhelinsoitto'
cltOutgoingP2P = u'L\xe4htev\xe4 vertaissoitto'
cltOutgoingPSTN = u'L\xe4htev\xe4 puhelinsoitto'
cltUnknown = u'Tuntematon'
cmeAddedMembers = u'Lis\xe4tty j\xe4senet'
cmeCreatedChatWith = u'Luotu chat-yhteys'
cmeEmoted = u'Tuntematon'
cmeLeft = u'Poistunut'
cmeSaid = u'Sanottu'
cmeSawMembers = u'N\xe4hty j\xe4senet'
cmeSetTopic = u'Aseta aihe'
cmeUnknown = u'Tuntematon'
cmsRead = u'Lue'
cmsReceived = u'Vastaanotettu'
cmsSending = u'L\xe4hetet\xe4\xe4n...'
cmsSent = u'L\xe4hetetty'
cmsUnknown = u'Tuntematon'
conConnecting = u'Yhdistet\xe4\xe4n'
conOffline = u'Offline-tila'
conOnline = u'Online-tila'
conPausing = u'Tauko'
conUnknown = u'Tuntematon'
cusAway = u'Poistunut'
cusDoNotDisturb = u'\xc4l\xe4 h\xe4iritse'
cusInvisible = u'Huomaamaton'
cusLoggedOut = u'Offline-tila'
cusNotAvailable = u'Ei saatavilla'
cusOffline = u'Offline-tila'
cusOnline = u'Online-tila'
cusSkypeMe = u'Soita minulle'
cusUnknown = u'Tuntematon'
cvsBothEnabled = u'Videon l\xe4hetys ja vastaanotto'
cvsNone = u'Ei videota'
cvsReceiveEnabled = u'Videon vastaanotto'
cvsSendEnabled = u'Videon l\xe4hetys'
cvsUnknown = u''
grpAllFriends = u'Kaikki yst\xe4v\xe4t'
grpAllUsers = u'Kaikki k\xe4ytt\xe4j\xe4t'
grpCustomGroup = u'R\xe4\xe4t\xe4l\xf6ity'
grpOnlineFriends = u'Netiss\xe4 olevat yst\xe4v\xe4t'
grpPendingAuthorizationFriends = u'Odottaa valtuutusta'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'\xc4skett\xe4iset yhteydet'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-yst\xe4v\xe4t'
grpSkypeOutFriends = u'SkypeOut-yst\xe4v\xe4t'
grpUngroupedFriends = u'Ryhmitt\xe4m\xe4tt\xf6m\xe4t yst\xe4v\xe4ni'
grpUnknown = u'Tuntematon'
grpUsersAuthorizedByMe = u'Valtuutin'
grpUsersBlockedByMe = u'Estin'
grpUsersWaitingMyAuthorization = u'Odottaa valtuutustani'
leaAddDeclined = u'Lis\xe4ys torjuttu'
leaAddedNotAuthorized = u'Lis\xe4tyn t\xe4ytyy olla valtuutettu'
leaAdderNotFriend = u'Lis\xe4\xe4j\xe4n t\xe4ytyy olla yst\xe4v\xe4'
leaUnknown = u'Tuntematon'
leaUnsubscribe = u'Ei tilaaja'
leaUserIncapable = u'K\xe4ytt\xe4j\xe4 esteellinen'
leaUserNotFound = u'K\xe4ytt\xe4j\xe4\xe4 ei l\xf6ytynyt'
olsAway = u'Poistunut'
olsDoNotDisturb = u'\xc4l\xe4 h\xe4iritse'
olsNotAvailable = u'Ei saatavilla'
olsOffline = u'Offline-tila'
olsOnline = u'Online-tila'
olsSkypeMe = u'Soita minulle'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Tuntematon'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Nainen'
usexMale = u'Mies'
usexUnknown = u'Tuntematon'
vmrConnectError = u'Yhdist\xe4misvirhe'
vmrFileReadError = u'Tiedostonlukuvirhe'
vmrFileWriteError = u'Tiedostonkirjoitusvirhe'
vmrMiscError = u'Sekal virhe'
vmrNoError = u'Ei virhett\xe4'
vmrNoPrivilege = u'Ei puhepostioikeutta'
vmrNoVoicemail = u'Tuntematon puheposti'
vmrPlaybackError = u'Toistovirhe'
vmrRecordingError = u'Tallennusvirhe'
vmrUnknown = u'Tuntematon'
vmsBlank = u'Tyhj\xe4'
vmsBuffering = u'Puskuroidaan'
vmsDeleting = u'Poistetaan'
vmsDownloading = u'Imuroidaan'
vmsFailed = u'Ep\xe4onnistui'
vmsNotDownloaded = u'Ei imuroitu'
vmsPlayed = u'Toistettu'
vmsPlaying = u'Toistetaan'
vmsRecorded = u'Tallennettu'
vmsRecording = u'Puhepostin \xe4\xe4nitys'
vmsUnknown = u'Tuntematon'
vmsUnplayed = u'Ei toistettu'
vmsUploaded = u'Ladattu'
vmsUploading = u'Ladataan'
vmtCustomGreeting = u'R\xe4\xe4t\xe4l\xf6ity tervehdys'
vmtDefaultGreeting = u'Oletustervehdys'
vmtIncoming = u'saapuva puheposti'
vmtOutgoing = u'L\xe4htev\xe4'
vmtUnknown = u'Tuntematon'
vssAvailable = u'Saatavilla'
vssNotAvailable = u'Ei saatavilla'
vssPaused = u'Tauko'
vssRejected = u'Torjuttu'
vssRunning = u'Meneill\xe4\xe4n'
vssStarting = u'Aloittaa'
vssStopping = u'Lopetetaan'
vssUnknown = u'Tuntematon'



"""
Low level *Skype for Linux* interface implemented using *XWindows messaging*.
Uses direct *Xlib* calls through *ctypes* module.

This module handles the options that you can pass to `Skype.__init__`
for Linux machines when the transport is set to *X11*.

No further options are currently supported.

Warning PyGTK framework users
=============================

The multithreaded architecture of Skype4Py requires a special treatment
if the Xlib transport is combined with PyGTK GUI framework.

The following code has to be called at the top of your script, before
PyGTK is even imported.

.. python::

    from Skype4Py.api.posix_x11 import threads_init
    threads_init()

This function enables multithreading support in Xlib and GDK. If not done
here, this is enabled for Xlib library when the `Skype` object is instantiated.
If your script imports the PyGTK module, doing this so late may lead to a
segmentation fault when the GUI is shown on the screen.

A remedy is to enable the multithreading support before PyGTK is imported
by calling the ``threads_init`` function.
"""
__docformat__ = 'restructuredtext en'


import sys
import threading
import os
from ctypes import *

from ctypes.util import find_library
import time
import logging

from Skype4Py.api import Command, SkypeAPIBase, \
                         timeout2float, finalize_opts
from Skype4Py.enums import *
from Skype4Py.errors import SkypeAPIError


__all__ = ['SkypeAPI', 'threads_init']


# The Xlib Programming Manual:
# ============================
# http://tronche.com/gui/x/xlib/


# some Xlib constants
PropertyChangeMask = 0x400000
PropertyNotify = 28
ClientMessage = 33
PropertyNewValue = 0
PropertyDelete = 1


# some Xlib types
c_ulong_p = POINTER(c_ulong)
DisplayP = c_void_p
Atom = c_ulong
AtomP = c_ulong_p
XID = c_ulong
Window = XID
Bool = c_int
Status = c_int
Time = c_ulong
c_int_p = POINTER(c_int)


# should the structures be aligned to 8 bytes?
align = (sizeof(c_long) == 8 and sizeof(c_int) == 4)


# some Xlib structures
class XClientMessageEvent(Structure):
    if align:
        _fields_ = [('type', c_int),
                    ('pad0', c_int),
                    ('serial', c_ulong),
                    ('send_event', Bool),
                    ('pad1', c_int),
                    ('display', DisplayP),
                    ('window', Window),
                    ('message_type', Atom),
                    ('format', c_int),
                    ('pad2', c_int),
                    ('data', c_char * 20)]
    else:
        _fields_ = [('type', c_int),
                    ('serial', c_ulong),
                    ('send_event', Bool),
                    ('display', DisplayP),
                    ('window', Window),
                    ('message_type', Atom),
                    ('format', c_int),
                    ('data', c_char * 20)]

class XPropertyEvent(Structure):
    if align:
        _fields_ = [('type', c_int),
                    ('pad0', c_int),
                    ('serial', c_ulong),
                    ('send_event', Bool),
                    ('pad1', c_int),
                    ('display', DisplayP),
                    ('window', Window),
                    ('atom', Atom),
                    ('time', Time),
                    ('state', c_int),
                    ('pad2', c_int)]
    else:
        _fields_ = [('type', c_int),
                    ('serial', c_ulong),
                    ('send_event', Bool),
                    ('display', DisplayP),
                    ('window', Window),
                    ('atom', Atom),
                    ('time', Time),
                    ('state', c_int)]

class XErrorEvent(Structure):
    if align:
        _fields_ = [('type', c_int),
                    ('pad0', c_int),
                    ('display', DisplayP),
                    ('resourceid', XID),
                    ('serial', c_ulong),
                    ('error_code', c_ubyte),
                    ('request_code', c_ubyte),
                    ('minor_code', c_ubyte)]
    else:
        _fields_ = [('type', c_int),
                    ('display', DisplayP),
                    ('resourceid', XID),
                    ('serial', c_ulong),
                    ('error_code', c_ubyte),
                    ('request_code', c_ubyte),
                    ('minor_code', c_ubyte)]

class XEvent(Union):
    if align:
        _fields_ = [('type', c_int),
                    ('xclient', XClientMessageEvent),
                    ('xproperty', XPropertyEvent),
                    ('xerror', XErrorEvent),
                    ('pad', c_long * 24)]
    else:
        _fields_ = [('type', c_int),
                    ('xclient', XClientMessageEvent),
                    ('xproperty', XPropertyEvent),
                    ('xerror', XErrorEvent),
                    ('pad', c_long * 24)]

XEventP = POINTER(XEvent)


if getattr(sys, 'skype4py_setup', False):
    # we get here if we're building docs; to let the module import without
    # exceptions, we emulate the X11 library using a class:
    class X(object):
        def __getattr__(self, name):
            return self
        def __setattr__(self, name, value):
            pass
        def __call__(self, *args, **kwargs):
            pass
    x11 = X()
else:
    # load X11 library (Xlib)
    libpath = find_library('X11')
    if not libpath:
        raise ImportError('Could not find X11 library')
    x11 = cdll.LoadLibrary(libpath)
    del libpath


# setup Xlib function prototypes
x11.XCloseDisplay.argtypes = (DisplayP,)
x11.XCloseDisplay.restype = None
x11.XCreateSimpleWindow.argtypes = (DisplayP, Window, c_int, c_int, c_uint,
        c_uint, c_uint, c_ulong, c_ulong)
x11.XCreateSimpleWindow.restype = Window
x11.XDefaultRootWindow.argtypes = (DisplayP,)
x11.XDefaultRootWindow.restype = Window
x11.XDeleteProperty.argtypes = (DisplayP, Window, Atom)
x11.XDeleteProperty.restype = None
x11.XDestroyWindow.argtypes = (DisplayP, Window)
x11.XDestroyWindow.restype = None
x11.XFree.argtypes = (c_void_p,)
x11.XFree.restype = None
x11.XGetAtomName.argtypes = (DisplayP, Atom)
x11.XGetAtomName.restype = c_void_p
x11.XGetErrorText.argtypes = (DisplayP, c_int, c_char_p, c_int)
x11.XGetErrorText.restype = None
x11.XGetWindowProperty.argtypes = (DisplayP, Window, Atom, c_long, c_long, Bool,
        Atom, AtomP, c_int_p, c_ulong_p, c_ulong_p, POINTER(POINTER(Window)))
x11.XGetWindowProperty.restype = c_int
x11.XInitThreads.argtypes = ()
x11.XInitThreads.restype = Status
x11.XInternAtom.argtypes = (DisplayP, c_char_p, Bool)
x11.XInternAtom.restype = Atom
x11.XNextEvent.argtypes = (DisplayP, XEventP)
x11.XNextEvent.restype = None
x11.XOpenDisplay.argtypes = (c_char_p,)
x11.XOpenDisplay.restype = DisplayP
x11.XPending.argtypes = (DisplayP,)
x11.XPending.restype = c_int
x11.XSelectInput.argtypes = (DisplayP, Window, c_long)
x11.XSelectInput.restype = None
x11.XSendEvent.argtypes = (DisplayP, Window, Bool, c_long, XEventP)
x11.XSendEvent.restype = Status
x11.XLockDisplay.argtypes = (DisplayP,)
x11.XLockDisplay.restype = None
x11.XUnlockDisplay.argtypes = (DisplayP,)
x11.XUnlockDisplay.restype = None


def threads_init(gtk=True):
    """Enables multithreading support in Xlib and PyGTK.
    See the module docstring for more info.
    
    :Parameters:
      gtk : bool
        May be set to False to skip the PyGTK module.
    """
    # enable X11 multithreading
    x11.XInitThreads()
    if gtk:
        from gtk.gdk import threads_init
        threads_init()


class SkypeAPI(SkypeAPIBase):
    def __init__(self, opts):
        self.logger = logging.getLogger('Skype4Py.api.posix_x11.SkypeAPI')
        SkypeAPIBase.__init__(self)
        finalize_opts(opts)
        
        # initialize threads if not done already by the user
        threads_init(gtk=False)

        # init Xlib display
        self.disp = x11.XOpenDisplay(None)
        if not self.disp:
            raise SkypeAPIError('Could not open XDisplay')
        self.win_root = x11.XDefaultRootWindow(self.disp)
        self.win_self = x11.XCreateSimpleWindow(self.disp, self.win_root,
                                                100, 100, 100, 100, 1, 0, 0)
        x11.XSelectInput(self.disp, self.win_root, PropertyChangeMask)
        self.win_skype = self.get_skype()
        ctrl = 'SKYPECONTROLAPI_MESSAGE'
        self.atom_msg = x11.XInternAtom(self.disp, ctrl, False)
        self.atom_msg_begin = x11.XInternAtom(self.disp, ctrl + '_BEGIN', False)

        self.loop_event = threading.Event()
        self.loop_timeout = 0.0001
        self.loop_break = False

    def __del__(self):
        if x11:
            if hasattr(self, 'disp'):
                if hasattr(self, 'win_self'):
                    x11.XDestroyWindow(self.disp, self.win_self)
                x11.XCloseDisplay(self.disp)

    def run(self):
        self.logger.info('thread started')
        # main loop
        event = XEvent()
        data = ''
        while not self.loop_break and x11:
            while x11.XPending(self.disp):
                self.loop_timeout = 0.0001
                x11.XNextEvent(self.disp, byref(event))
                # events we get here are already prefiltered by the predicate function
                if event.type == ClientMessage:
                    if event.xclient.format == 8:
                        if event.xclient.message_type == self.atom_msg_begin:
                            data = str(event.xclient.data)
                        elif event.xclient.message_type == self.atom_msg:
                            if data != '':
                                data += str(event.xclient.data)
                            else:
                                self.logger.warning('Middle of Skype X11 message received with no beginning!')
                        else:
                            continue
                        if len(event.xclient.data) != 20 and data:
                            self.notify(data.decode('utf-8'))
                            data = ''
                elif event.type == PropertyNotify:
                    namep = x11.XGetAtomName(self.disp, event.xproperty.atom)
                    is_inst = (c_char_p(namep).value == '_SKYPE_INSTANCE')
                    x11.XFree(namep)
                    if is_inst:
                        if event.xproperty.state == PropertyNewValue:
                            self.win_skype = self.get_skype()
                            # changing attachment status can cause an event handler to be fired, in
                            # turn it could try to call Attach() and doing this immediately seems to
                            # confuse Skype (command '#0 NAME xxx' returns '#0 CONNSTATUS OFFLINE' :D);
                            # to fix this, we give Skype some time to initialize itself
                            time.sleep(1.0)
                            self.set_attachment_status(apiAttachAvailable)
                        elif event.xproperty.state == PropertyDelete:
                            self.win_skype = None
                            self.set_attachment_status(apiAttachNotAvailable)
            self.loop_event.wait(self.loop_timeout)
            if self.loop_event.isSet():
                self.loop_timeout = 0.0001
            elif self.loop_timeout < 1.0:
                self.loop_timeout *= 2
            self.loop_event.clear()
        self.logger.info('thread finished')
   
    def get_skype(self):
        """Returns Skype window ID or None if Skype not running."""
        skype_inst = x11.XInternAtom(self.disp, '_SKYPE_INSTANCE', True)
        if not skype_inst:
            return
        type_ret = Atom()
        format_ret = c_int()
        nitems_ret = c_ulong()
        bytes_after_ret = c_ulong()
        winp = pointer(Window())
        fail = x11.XGetWindowProperty(self.disp, self.win_root, skype_inst,
                            0, 1, False, 33, byref(type_ret), byref(format_ret),
                            byref(nitems_ret), byref(bytes_after_ret), byref(winp))
        if not fail and format_ret.value == 32 and nitems_ret.value == 1:
            return winp.contents.value

    def close(self):
        self.loop_break = True
        self.loop_event.set()
        while self.isAlive():
            time.sleep(0.01)
        SkypeAPIBase.close(self)

    def set_friendly_name(self, friendly_name):
        SkypeAPIBase.set_friendly_name(self, friendly_name)
        if self.attachment_status == apiAttachSuccess:
            # reattach with the new name
            self.set_attachment_status(apiAttachUnknown)
            self.attach()

    def attach(self, timeout, wait=True):
        if self.attachment_status == apiAttachSuccess:
            return
        self.acquire()
        try:
            if not self.isAlive():
                try:
                    self.start()
                except AssertionError:
                    raise SkypeAPIError('Skype API closed')
            try:
                self.wait = True
                t = threading.Timer(timeout2float(timeout), lambda: setattr(self, 'wait', False))
                if wait:
                    t.start()
                while self.wait:
                    self.win_skype = self.get_skype()
                    if self.win_skype is not None:
                        break
                    else:
                        time.sleep(1.0)
                else:
                    raise SkypeAPIError('Skype attach timeout')
            finally:
                t.cancel()
            command = Command('NAME %s' % self.friendly_name, '', True, timeout)
            self.release()
            try:
                self.send_command(command, True)
            finally:
                self.acquire()
            if command.Reply != 'OK':
                self.win_skype = None
                self.set_attachment_status(apiAttachRefused)
                return
            self.set_attachment_status(apiAttachSuccess)
        finally:
            self.release()
        command = Command('PROTOCOL %s' % self.protocol, Blocking=True)
        self.send_command(command, True)
        self.protocol = int(command.Reply.rsplit(None, 1)[-1])

    def is_running(self):
        return (self.get_skype() is not None)

    def startup(self, minimized, nosplash):
        # options are not supported as of Skype 1.4 Beta for Linux
        if not self.is_running():
            if os.fork() == 0: # we're the child
                os.setsid()
                os.execlp('skype', 'skype')

    def shutdown(self):
        from signal import SIGINT
        fh = os.popen('ps -o %p --no-heading -C skype')
        pid = fh.readline().strip()
        fh.close()
        if pid:
            os.kill(int(pid), SIGINT)
            # Skype sometimes doesn't delete the '_SKYPE_INSTANCE' property
            skype_inst = x11.XInternAtom(self.disp, '_SKYPE_INSTANCE', True)
            if skype_inst:
                x11.XDeleteProperty(self.disp, self.win_root, skype_inst)
            self.win_skype = None
            self.set_attachment_status(apiAttachNotAvailable)

    def send_command(self, command, force=False):
        if self.attachment_status != apiAttachSuccess and not force:
            self.attach(command.Timeout)
        self.push_command(command)
        self.notifier.sending_command(command)
        cmd = u'#%d %s' % (command.Id, command.Command)
        self.logger.debug('sending %s', repr(cmd))
        if command.Blocking:
            command._event = bevent = threading.Event()
        else:
            command._timer = timer = threading.Timer(command.timeout2float(), self.pop_command, (command.Id,))
        event = XEvent()
        event.xclient.type = ClientMessage
        event.xclient.display = self.disp
        event.xclient.window = self.win_self
        event.xclient.message_type = self.atom_msg_begin
        event.xclient.format = 8
        cmd = cmd.encode('utf-8') + '\x00'
        for i in xrange(0, len(cmd), 20):
            event.xclient.data = cmd[i:i + 20]
            x11.XSendEvent(self.disp, self.win_skype, False, 0, byref(event))
            event.xclient.message_type = self.atom_msg
        self.loop_event.set()
        if command.Blocking:
            bevent.wait(command.timeout2float())
            if not bevent.isSet():
                raise SkypeAPIError('Skype command timeout')
        else:
            timer.start()

    def notify(self, cmd):
        self.logger.debug('received %s', repr(cmd))
        # Called by main loop for all received Skype commands.
        if cmd.startswith(u'#'):
            p = cmd.find(u' ')
            command = self.pop_command(int(cmd[1:p]))
            if command is not None:
                command.Reply = cmd[p + 1:]
                if command.Blocking:
                    command._event.set()
                else:
                    command._timer.cancel()
                self.notifier.reply_received(command)
            else:
                self.notifier.notification_received(cmd[p + 1:])
        else:
            self.notifier.notification_received(cmd)



"""Data channels for calls.
"""
__docformat__ = 'restructuredtext en'


import time
from copy import copy

from utils import *
from enums import *
from errors import SkypeError


class CallChannelManager(EventHandlingBase):
    """Instantiate this class to create a call channel manager. A call channel manager will
    automatically create a data channel (based on the APP2APP protocol) for voice calls.

    Usage
    =====

       You should access this class using the alias at the package level:
       
       .. python::

           import Skype4Py

           skype = Skype4Py.Skype()

           ccm = Skype4Py.CallChannelManager()
           ccm.Connect(skype)

       Read the constructor (`CallChannelManager.__init__`) documentation for a list of
       accepted arguments.

    Events
    ======

       This class provides events.

       The events names and their arguments lists can be found in the
       `CallChannelManagerEvents` class in this module.

       The use of events is explained in `EventHandlingBase` class which
       is a superclass of this class.
    """

    def __del__(self):
        if getattr(self, '_App', None):
            self._App.Delete()
            self._App = None
            self._Skype.UnregisterEventHandler('ApplicationStreams', self._OnApplicationStreams)
            self._Skype.UnregisterEventHandler('ApplicationReceiving', self._OnApplicationReceiving)
            self._Skype.UnregisterEventHandler('ApplicationDatagram', self._OnApplicationDatagram)

    def __init__(self, Events=None, Skype=None):
        """Initializes the object.
        
        :Parameters:
          Events
            An optional object with event handlers. See `EventHandlingBase` for more
            information on events.
        """
        EventHandlingBase.__init__(self)
        if Events:
            self._SetEventHandlerObj(Events)

        self._App = None
        self._Name = u'CallChannelManager'
        self._ChannelType = cctReliable
        self._Channels = []
        self.Connect(Skype)

    def _ApplicationDatagram(self, App, Stream, Text):
        if App == self._App:
            for ch in self_Channels:
                if ch['stream'] == Stream:
                    msg = CallChannelMessage(Text)
                    self._CallEventHandler('Message', self, CallChannel(self, ch), msg)
                    break

    def _ApplicationReceiving(self, App, Streams):
        if App == self._App:
            for ch in self._Channels:
                if ch['stream'] in Streams:
                    msg = CallChannelMessage(ch.Stream.Read())
                    self._CallEventHandler('Message', self, CallChannel(self, ch), msg)

    def _ApplicationStreams(self, App, Streams):
        if App == self._App:
            for ch in self._Channels:
                if ch['stream'] not in Streams:
                    self._Channels.remove(ch)
                    self._CallEventHandler('Channels', self, self.Channels)

    def _CallStatus(self, Call, Status):
        if Status == clsRinging:
            if self._App is None:
                self.CreateApplication()
            self._App.Connect(Call.PartnerHandle, True)
            for stream in self._App.Streams:
                if stream.PartnerHandle == Call.PartnerHandle:
                    self._Channels.append(dict(call=Call, stream=stream))
                    self._CallEventHandler('Channels', self, self.Channels)
                    break
        elif Status in (clsCancelled, clsFailed, clsFinished, clsRefused, clsMissed):
            for ch in self._Channels:
                if ch['call'] == Call:
                    self._Channels.remove(ch)
                    self._CallEventHandler('Channels', self, self.Channels)
                    try:
                        ch['stream'].Disconnect()
                    except SkypeError:
                        pass
                    break

    def Connect(self, Skype):
        """Connects this call channel manager instance to Skype. This is the first thing you should
        do after creating this object.

        :Parameters:
          Skype : `Skype`
            The Skype object.

        :see: `Disconnect`
        """
        self._Skype = Skype
        self._Skype.RegisterEventHandler('CallStatus', self._CallStatus)
        del self._Channels[:]

    def CreateApplication(self, ApplicationName=None):
        """Creates an APP2APP application context. The application is automatically created using
        `application.Application.Create` method.
        
        :Parameters:
          ApplicationName : unicode
            Application name. Initial name, when the manager is created, is ``u'CallChannelManager'``.
        """
        if ApplicationName is not None:
            self.Name = tounicode(ApplicationName)
        self._App = self._Skype.Application(self.Name)
        self._Skype.RegisterEventHandler('ApplicationStreams', self._ApplicationStreams)
        self._Skype.RegisterEventHandler('ApplicationReceiving', self._ApplicationReceiving)
        self._Skype.RegisterEventHandler('ApplicationDatagram', self._ApplicationDatagram)
        self._App.Create()
        self._CallEventHandler('Created', self)

    def Disconnect(self):
        """Disconnects from the Skype instance.
        
        :see: `Connect`
        """
        self._Skype.UnregisterEventHandler('CallStatus', self._CallStatus)
        self._Skype = None

    def _GetChannels(self):
        return tuple(self._Channels)

    Channels = property(_GetChannels,
    doc="""All call data channels.

    :type: tuple of `CallChannel`
    """)

    def _GetChannelType(self):
        return self._ChannelType

    def _SetChannelType(self, Value):
        self._ChannelType = str(Value)

    ChannelType = property(_GetChannelType, _SetChannelType,
    doc="""Queries/sets the default channel type.

    :type: `enums`.cct*
    """)

    def _GetCreated(self):
        return (not not self._App)

    Created = property(_GetCreated,
    doc="""Returns True if the application context has been created.

    :type: bool
    """)

    def _GetName(self):
        return self._Name

    def _SetName(self, Value):
        self._Name = tounicode(Value)

    Name = property(_GetName, _SetName,
    doc="""Queries/sets the application context name.

    :type: unicode
    """)


class CallChannelManagerEvents(object):
    """Events defined in `CallChannelManager`.

    See `EventHandlingBase` for more information on events.
    """

    def Channels(self, Manager, Channels):
        """This event is triggered when list of call channels changes.

        :Parameters:
          Manager : `CallChannelManager`
            The call channel manager object.
          Channels : tuple of `CallChannel`
            Updated list of call channels.
        """

    def Created(self, Manager):
        """This event is triggered when the application context has successfully been created.

        :Parameters:
          Manager : `CallChannelManager`
            The call channel manager object.
        """

    def Message(self, Manager, Channel, Message):
        """This event is triggered when a call channel message has been received.

        :Parameters:
          Manager : `CallChannelManager`
            The call channel manager object.
          Channel : `CallChannel`
            The call channel object receiving the message.
          Message : `CallChannelMessage`
            The received message.
        """


CallChannelManager._AddEvents(CallChannelManagerEvents)


class CallChannel(object):
    """Represents a call channel.
    """

    def __repr__(self):
        return Cached.__repr__(self, 'Manager', 'Call', 'Stream')

    def SendTextMessage(self, Text):
        """Sends a text message over channel.

        :Parameters:
          Text : unicode
            Text to send.
        """
        if self.Type == cctReliable:
            self.Stream.Write(Text)
        elif self.Type == cctDatagram:
            self.Stream.SendDatagram(Text)
        else:
            raise SkypeError(0, 'Cannot send using %s channel type' & repr(self.Type))

    def _GetCall(self):
        return self._Handle['call']

    Call = property(_GetCall,
    doc="""The call object associated with this channel.

    :type: `Call`
    """)

    def _GetManager(self):
        return self._Owner

    Manager = property(_GetManager,
    doc="""The call channel manager object.

    :type: `CallChannelManager`
    """)

    def _GetStream(self):
        return self._Handle['stream']

    Stream = property(_GetStream,
    doc="""Underlying APP2APP stream object.

    :type: `ApplicationStream`
    """)

    def _GetType(self):
        return self._Handle.get('type', self.Manager.ChannelType)

    def _SetType(self, Value):
        self._Handle['type'] = str(Value)

    Type = property(_GetType, _SetType,
    doc="""Type of this channel.

    :type: `enums`.cct*
    """)


class CallChannelMessage(object):
    """Represents a call channel message.
    """

    def __init__(self, Text):
        """Initializes the object.

        :Parameters:
          Text : unicode
            The message text.
        """
        self._Text = tounicode(Text)

    def _GetText(self):
        return self._Text

    def _SetText(self, Value):
        self._Text = tounicode(Value)

    Text = property(_GetText, _SetText,
    doc="""Queries/sets the message text.

    :type: unicode
    """)



apiAttachAvailable = u'API disponible'
apiAttachNotAvailable = u'No disponible'
apiAttachPendingAuthorization = u'Autorizaci\xf3n pendiente'
apiAttachRefused = u'Rechazado'
apiAttachSuccess = u'Conectado'
apiAttachUnknown = u'Desconocido'
budDeletedFriend = u'Borrado de la lista de contactos'
budFriend = u'Contacto'
budNeverBeenFriend = u'Nunca estuvo en la lista de contactos'
budPendingAuthorization = u'Autorizaci\xf3n pendiente'
budUnknown = u'Desconocido'
cfrBlockedByRecipient = u'Llamada bloqueada por el destinatario'
cfrMiscError = u'Error de car\xe1cter general'
cfrNoCommonCodec = u'Ning\xfan c\xf3dec com\xfan'
cfrNoProxyFound = u'No se encontr\xf3 proxy'
cfrNotAuthorizedByRecipient = u'El usuario actual no est\xe1 autorizado por el destinatario'
cfrRecipientNotFriend = u'El destinatario no es un contacto'
cfrRemoteDeviceError = u'Existe un problema con el dispositivo de sonido remoto'
cfrSessionTerminated = u'Sesi\xf3n terminada'
cfrSoundIOError = u'Error de E/S de sonido'
cfrSoundRecordingError = u'Error de grabaci\xf3n de sonido'
cfrUnknown = u'Desconocido'
cfrUserDoesNotExist = u'El usuario o el n\xfamero telef\xf3nico no existen'
cfrUserIsOffline = u'Est\xe1 desconectado/a'
chsAllCalls = u'Di\xe1logos heredados'
chsDialog = u'Di\xe1logo'
chsIncomingCalls = u'Esperando aceptaci\xf3n grupal'
chsLegacyDialog = u'Di\xe1logos heredados'
chsMissedCalls = u'Di\xe1logo'
chsMultiNeedAccept = u'Esperando aceptaci\xf3n grupal'
chsMultiSubscribed = u'Grupal suscrita'
chsOutgoingCalls = u'Grupal suscrita'
chsUnknown = u'Desconocido'
chsUnsubscribed = u'No suscrito'
clsBusy = u'Ocupado'
clsCancelled = u'Cancelado'
clsEarlyMedia = u'Reproduciendo medios iniciales (Early Media)'
clsFailed = u'Perd\xf3n, llamada fallida!'
clsFinished = u'Finalizada'
clsInProgress = u'Llamada en curso'
clsLocalHold = u'En espera local'
clsMissed = u'Llamada perdida'
clsOnHold = u'En espera'
clsRefused = u'Rechazado'
clsRemoteHold = u'En espera remota'
clsRinging = u'helistanud'
clsRouting = u'Enrutando'
clsTransferred = u'Desconocido'
clsTransferring = u'Desconocido'
clsUnknown = u'Desconocido'
clsUnplaced = u'Nunca se realiz\xf3'
clsVoicemailBufferingGreeting = u'Almacenando saludo en el b\xfafer'
clsVoicemailCancelled = u'Mensaje de voz cancelado'
clsVoicemailFailed = u'Fallo del buz\xf3n del voz'
clsVoicemailPlayingGreeting = u'Reproduciendo saludo'
clsVoicemailRecording = u'Grabando mensaje de voz'
clsVoicemailSent = u'Mensaje de voz enviado'
clsVoicemailUploading = u'Cargando mensaje de voz'
cltIncomingP2P = u'Llamada recibida de par a par'
cltIncomingPSTN = u'Llamada recibida'
cltOutgoingP2P = u'Llamada realizada de par a par'
cltOutgoingPSTN = u'Llamada realizada'
cltUnknown = u'Desconocido'
cmeAddedMembers = u'Miembros agregados'
cmeCreatedChatWith = u'Conversaci\xf3n iniciada con'
cmeEmoted = u'Desconocido'
cmeLeft = u'Conversaci\xf3n abandonada'
cmeSaid = u'Dijo'
cmeSawMembers = u'Miembros vistos'
cmeSetTopic = u'Definici\xf3n del tema'
cmeUnknown = u'Desconocido'
cmsRead = u'Le\xeddo'
cmsReceived = u'Recibido'
cmsSending = u'Enviando...'
cmsSent = u'Enviado'
cmsUnknown = u'Desconocido'
conConnecting = u'Conectando'
conOffline = u'Desconectado'
conOnline = u'Conectado'
conPausing = u'En pausa'
conUnknown = u'Desconocido'
cusAway = u'Ausente'
cusDoNotDisturb = u'Ocupado'
cusInvisible = u'Invisible'
cusLoggedOut = u'Desconectado'
cusNotAvailable = u'No disponible'
cusOffline = u'Desconectado'
cusOnline = u'Conectado'
cusSkypeMe = u'Skyp\xe9ame'
cusUnknown = u'Desconocido'
cvsBothEnabled = u'Enviando y recibiendo video'
cvsNone = u'Sin video'
cvsReceiveEnabled = u'Recibiendo video'
cvsSendEnabled = u'Enviando video'
cvsUnknown = u''
grpAllFriends = u'Todos los contactos'
grpAllUsers = u'Todos los usuarios'
grpCustomGroup = u'Personalizado'
grpOnlineFriends = u'Contactos conectados'
grpPendingAuthorizationFriends = u'Autorizaci\xf3n pendiente'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Usuarios contactados recientemente'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Contactos de Skype'
grpSkypeOutFriends = u'Contactos de SkypeOut'
grpUngroupedFriends = u'Contactos no agrupados'
grpUnknown = u'Desconocido'
grpUsersAuthorizedByMe = u'Autorizado por m\xed'
grpUsersBlockedByMe = u'Bloqueado por m\xed'
grpUsersWaitingMyAuthorization = u'Esperando mi autorizaci\xf3n'
leaAddDeclined = u'Agregado rechazado'
leaAddedNotAuthorized = u'La persona agregada deber estar autorizada'
leaAdderNotFriend = u'Quien agrega debe ser un contacto'
leaUnknown = u'Desconocido'
leaUnsubscribe = u'No suscrito'
leaUserIncapable = u'Usuario inhabilitado'
leaUserNotFound = u'No se encontr\xf3 el usuario'
olsAway = u'Ausente'
olsDoNotDisturb = u'Ocupado'
olsNotAvailable = u'No disponible'
olsOffline = u'Desconectado'
olsOnline = u'Conectado'
olsSkypeMe = u'Skyp\xe9ame'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Desconocido'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Mujer'
usexMale = u'Hombre'
usexUnknown = u'Desconocido'
vmrConnectError = u'Error de conexi\xf3n'
vmrFileReadError = u'Error de lectura en archivo'
vmrFileWriteError = u'Error de escritura en archivo'
vmrMiscError = u'Error de car\xe1cter general'
vmrNoError = u'No se produjo error'
vmrNoPrivilege = u'Sin privilegio de mensaje de voz'
vmrNoVoicemail = u'Sin mensaje de voz'
vmrPlaybackError = u'Error de reproducci\xf3n'
vmrRecordingError = u'Error de grabaci\xf3n'
vmrUnknown = u'Desconocido'
vmsBlank = u'En blanco'
vmsBuffering = u'Almacenando'
vmsDeleting = u'Borrando'
vmsDownloading = u'Descargando'
vmsFailed = u'No enviado'
vmsNotDownloaded = u'No se descarg\xf3'
vmsPlayed = u'Reproducido'
vmsPlaying = u'Reproduciendo'
vmsRecorded = u'Grabado'
vmsRecording = u'Grabando mensaje de voz'
vmsUnknown = u'Desconocido'
vmsUnplayed = u'No se reprodujo'
vmsUploaded = u'Cargado'
vmsUploading = u'Cargando'
vmtCustomGreeting = u'Saludo personalizado'
vmtDefaultGreeting = u'Saludo predeterminado'
vmtIncoming = u'correo de voz entrante'
vmtOutgoing = u'Saliente'
vmtUnknown = u'Desconocido'
vssAvailable = u'Disponible'
vssNotAvailable = u'No disponible'
vssPaused = u'Interrumpida'
vssRejected = u'Rechazada'
vssRunning = u'En curso'
vssStarting = u'Iniciando'
vssStopping = u'Detenida'
vssUnknown = u'Desconocido'



"""Chats.
"""
__docformat__ = 'restructuredtext en'


from utils import *
from user import *
from errors import SkypeError


class Chat(Cached):
    """Represents a Skype chat.
    """
    _ValidateHandle = str

    def __repr__(self):
        return Cached.__repr__(self, 'Name')

    def _Alter(self, AlterName, Args=None):
        '''
        --- Prajna bug fix ---
        Original code:
        return self._Owner._Alter('CHAT', self.Name, AlterName, Args,
                                  'ALTER CHAT %s %s' % (self.Name, AlterName))
        Whereas most of the ALTER commands echo the command in the reply,
        the ALTER CHAT commands strip the <chat_id> from the reply,
        so we need to do the same for the expected reply
        '''
        return self._Owner._Alter('CHAT', self.Name, AlterName, Args,
                                  'ALTER CHAT %s' % (AlterName))

    def _Property(self, PropName, Value=None, Cache=True):
        return self._Owner._Property('CHAT', self.Name, PropName, Value, Cache)

    def AcceptAdd(self):
        """Accepts a shared group add request.
        """
        self._Alter('ACCEPTADD')

    def AddMembers(self, *Members):
        """Adds new members to the chat.

        :Parameters:
          Members : `User`
            One or more users to add.
        """
        self._Alter('ADDMEMBERS', ', '.join([x.Handle for x in Members]))

    def Bookmark(self):
        """Bookmarks the chat in Skype client.
        """
        self._Alter('BOOKMARK')

    def ClearRecentMessages(self):
        """Clears recent chat messages.
        """
        self._Alter('CLEARRECENTMESSAGES')

    def Disband(self):
        """Ends the chat.
        """
        self._Alter('DISBAND')

    def EnterPassword(self, Password):
        """Enters chat password.

        :Parameters:
          Password : unicode
            Password
        """
        self._Alter('ENTERPASSWORD', tounicode(Password))

    def Join(self):
        """Joins the chat.
        """
        self._Alter('JOIN')

    def Kick(self, *Handles):
        """Kicks member(s) from chat.

        :Parameters:
          Handles : str
            Skype username(s).
        """
        self._Alter('KICK', ', '.join(Handles))

    def KickBan(self, *Handles):
        """Kicks and bans member(s) from chat.

        :Parameters:
          Handles : str
            Skype username(s).
        """
        self._Alter('KICKBAN', ', '.join(Handles))

    def Leave(self):
        """Leaves the chat.
        """
        self._Alter('LEAVE')

    def OpenWindow(self):
        """Opens the chat window.
        """
        self._Owner.Client.OpenDialog('CHAT', self.Name)

    def SendMessage(self, MessageText):
        """Sends a chat message.

        :Parameters:
          MessageText : unicode
            Message text

        :return: Message object
        :rtype: `ChatMessage`
        """
        return ChatMessage(self._Owner, chop(self._Owner._DoCommand('CHATMESSAGE %s %s' % (self.Name,
            tounicode(MessageText))), 2)[1])

    def SetPassword(self, Password, Hint=''):
        """Sets the chat password.

        :Parameters:
          Password : unicode
            Password
          Hint : unicode
            Password hint
        """
        if ' ' in Password:
            raise ValueError('Password mut be one word')
        self._Alter('SETPASSWORD', '%s %s' % (tounicode(Password), tounicode(Hint)))

    def Unbookmark(self):
        """Unbookmarks the chat.
        """
        self._Alter('UNBOOKMARK')

    def _GetActiveMembers(self):
        return UserCollection(self._Owner, split(self._Property('ACTIVEMEMBERS', Cache=False)))

    ActiveMembers = property(_GetActiveMembers,
    doc="""Active members of a chat.

    :type: `UserCollection`
    """)

    def _GetActivityDatetime(self):
        from datetime import datetime
        return datetime.fromtimestamp(self.ActivityTimestamp)

    ActivityDatetime = property(_GetActivityDatetime,
    doc="""Returns chat activity timestamp as datetime.

    :type: datetime.datetime
    """)

    def _GetActivityTimestamp(self):
        return float(self._Property('ACTIVITY_TIMESTAMP'))

    ActivityTimestamp = property(_GetActivityTimestamp,
    doc="""Returns chat activity timestamp.

    :type: float

    :see: `ActivityDatetime`
    """)

    def _GetAdder(self):
        return User(self._Owner, self._Property('ADDER'))

    Adder = property(_GetAdder,
    doc="""Returns the user that added current user to the chat.

    :type: `User`
    """)

    def _SetAlertString(self, Value):
        self._Alter('SETALERTSTRING', quote('=%s' % tounicode(Value)))

    AlertString = property(fset=_SetAlertString,
    doc="""Chat alert string. Only messages containing words from this string will cause a
    notification to pop up on the screen.

    :type: unicode
    """)

    def _GetApplicants(self):
        return UserCollection(self._Owner, split(self._Property('APPLICANTS')))

    Applicants = property(_GetApplicants,
    doc="""Chat applicants.

    :type: `UserCollection`
    """)

    def _GetBlob(self):
        return str(self._Property('BLOB'))

    Blob = property(_GetBlob,
    doc="""Chat blob.

    :type: str
    """)

    def _GetBookmarked(self):
        return (self._Property('BOOKMARKED') == 'TRUE')

    Bookmarked = property(_GetBookmarked,
    doc="""Tells if this chat is bookmarked.

    :type: bool
    """)

    def _GetDatetime(self):
        from datetime import datetime
        return datetime.fromtimestamp(self.Timestamp)

    Datetime = property(_GetDatetime,
    doc="""Chat timestamp as datetime.

    :type: datetime.datetime
    """)

    def _GetDescription(self):
        return self._Property('DESCRIPTION')

    def _SetDescription(self, Value):
        self._Property('DESCRIPTION', tounicode(Value))

    Description = property(_GetDescription, _SetDescription,
    doc="""Chat description.

    :type: unicode
    """)

    def _GetDialogPartner(self):
        return str(self._Property('DIALOG_PARTNER'))

    DialogPartner = property(_GetDialogPartner,
    doc="""Skypename of the chat dialog partner.

    :type: str
    """)

    def _GetFriendlyName(self):
        return self._Property('FRIENDLYNAME')

    FriendlyName = property(_GetFriendlyName,
    doc="""Friendly name of the chat.

    :type: unicode
    """)

    def _GetGuideLines(self):
        return self._Property('GUIDELINES')

    def _SetGuideLines(self, Value):
        self._Alter('SETGUIDELINES', tounicode(Value))

    GuideLines = property(_GetGuideLines, _SetGuideLines,
    doc="""Chat guidelines.

    :type: unicode
    """)

    def _GetMemberObjects(self):
        return ChatMemberCollection(self._Owner, split(self._Property('MEMBEROBJECTS'), ', '))

    MemberObjects = property(_GetMemberObjects,
    doc="""Chat members as member objects.

    :type: `ChatMemberCollection`
    """)

    def _GetMembers(self):
        return UserCollection(self._Owner, split(self._Property('MEMBERS')))

    Members = property(_GetMembers,
    doc="""Chat members.

    :type: `UserCollection`
    """)

    def _GetMessages(self):
        return ChatMessageCollection(self._Owner, split(self._Property('CHATMESSAGES', Cache=False), ', '))

    Messages = property(_GetMessages,
    doc="""All chat messages.

    :type: `ChatMessageCollection`
    """)

    def _GetMyRole(self):
        return str(self._Property('MYROLE'))

    MyRole = property(_GetMyRole,
    doc="""My chat role in a public chat.

    :type: `enums`.chatMemberRole*
    """)

    def _GetMyStatus(self):
        return str(self._Property('MYSTATUS'))

    MyStatus = property(_GetMyStatus,
    doc="""My status in a public chat.

    :type: `enums`.chatStatus*
    """)

    def _GetName(self):
        return self._Handle

    Name = property(_GetName,
    doc="""Chat name as used by Skype to identify this chat.

    :type: str
    """)

    def _GetOptions(self):
        return int(self._Property('OPTIONS'))

    def _SetOptions(self, Value):
        self._Alter('SETOPTIONS', Value)

    Options = property(_GetOptions, _SetOptions,
    doc="""Chat options. A mask.

    :type: `enums`.chatOption*
    """)

    def _GetPasswordHint(self):
        return self._Property('PASSWORDHINT')

    PasswordHint = property(_GetPasswordHint,
    doc="""Chat password hint.

    :type: unicode
    """)

    def _GetPosters(self):
        return UserCollection(self._Owner, split(self._Property('POSTERS')))

    Posters = property(_GetPosters,
    doc="""Users who have posted messages to this chat.

    :type: `UserCollection`
    """)

    def _GetRecentMessages(self):
        return ChatMessageCollection(self._Owner, split(self._Property('RECENTCHATMESSAGES', Cache=False), ', '))

    RecentMessages = property(_GetRecentMessages,
    doc="""Most recent chat messages.

    :type: `ChatMessageCollection`
    """)

    def _GetStatus(self):
        return str(self._Property('STATUS'))

    Status = property(_GetStatus,
    doc="""Status.

    :type: `enums`.chs*
    """)

    def _GetTimestamp(self):
        return float(self._Property('TIMESTAMP'))

    Timestamp = property(_GetTimestamp,
    doc="""Chat timestamp.

    :type: float

    :see: `Datetime`
    """)

    # Note. When TOPICXML is set, the value is stripped of XML tags and updated in TOPIC.

    def _GetTopic(self):
        return self._Property('TOPIC')

    def _SetTopic(self, Value):
        self._Alter('SETTOPIC', tounicode(Value))

    Topic = property(_GetTopic, _SetTopic,
    doc="""Chat topic.

    :type: unicode
    """)

    def _GetTopicXML(self):
        return self._Property('TOPICXML')

    def _SetTopicXML(self, Value):
        self._Alter('SETTOPICXML', tounicode(Value))

    TopicXML = property(_GetTopicXML, _SetTopicXML,
    doc="""Chat topic in XML format.

    :type: unicode
    """)

    def _GetType(self):
        return str(self._Property('TYPE'))

    Type = property(_GetType,
    doc="""Chat type.

    :type: `enums`.chatType*
    """)


class ChatCollection(CachedCollection):
    _CachedType = Chat


class ChatMessage(Cached):
    """Represents a single chat message.
    """
    _ValidateHandle = int

    def __repr__(self):
        return Cached.__repr__(self, 'Id')

    def _Property(self, PropName, Value=None, Cache=True):
        return self._Owner._Property('CHATMESSAGE', self.Id, PropName, Value, Cache)

    def MarkAsSeen(self):
        """Marks a missed chat message as seen.
        """
        self._Owner._DoCommand('SET CHATMESSAGE %d SEEN' % self.Id, 'CHATMESSAGE %d STATUS READ' % self.Id)

    def _GetBody(self):
        return self._Property('BODY')

    def _SetBody(self, Value):
        self._Property('BODY', tounicode(Value))

    Body = property(_GetBody, _SetBody,
    doc="""Chat message body.

    :type: unicode
    """)

    def _GetChat(self):
        return Chat(self._Owner, self.ChatName)

    Chat = property(_GetChat,
    doc="""Chat this message was posted on.

    :type: `Chat`
    """)

    def _GetChatName(self):
        return str(self._Property('CHATNAME'))

    ChatName = property(_GetChatName,
    doc="""Name of the chat this message was posted on.

    :type: str
    """)

    def _GetDatetime(self):
        from datetime import datetime
        return datetime.fromtimestamp(self.Timestamp)

    Datetime = property(_GetDatetime,
    doc="""Chat message timestamp as datetime.

    :type: datetime.datetime
    """)

    def _GetEditedBy(self):
        return str(self._Property('EDITED_BY'))

    EditedBy = property(_GetEditedBy,
    doc="""Skypename of the user who edited this message.

    :type: str
    """)

    def _GetEditedDatetime(self):
        from datetime import datetime
        return datetime.fromtimestamp(self.EditedTimestamp)

    EditedDatetime = property(_GetEditedDatetime,
    doc="""Message editing timestamp as datetime.

    :type: datetime.datetime
    """)

    def _GetEditedTimestamp(self):
        return float(self._Property('EDITED_TIMESTAMP'))

    EditedTimestamp = property(_GetEditedTimestamp,
    doc="""Message editing timestamp.

    :type: float
    """)

    def _GetFromDisplayName(self):
        return self._Property('FROM_DISPNAME')

    FromDisplayName = property(_GetFromDisplayName,
    doc="""DisplayName of the message sender.

    :type: unicode
    """)

    def _GetFromHandle(self):
        return str(self._Property('FROM_HANDLE'))

    FromHandle = property(_GetFromHandle,
    doc="""Skypename of the message sender.

    :type: str
    """)

    def _GetId(self):
        return self._Handle

    Id = property(_GetId,
    doc="""Chat message Id.

    :type: int
    """)

    def _GetIsEditable(self):
        return (self._Property('IS_EDITABLE') == 'TRUE')

    IsEditable = property(_GetIsEditable,
    doc="""Tells if message body is editable.

    :type: bool
    """)

    def _GetLeaveReason(self):
        return str(self._Property('LEAVEREASON'))

    LeaveReason = property(_GetLeaveReason,
    doc="""LeaveReason.

    :type: `enums`.lea*
    """)

    def _SetSeen(self, Value):
        from warnings import warn
        warn('ChatMessage.Seen = x: Use ChatMessage.MarkAsSeen() instead.', DeprecationWarning, stacklevel=2)
        if Value:
            self.MarkAsSeen()
        else:
            raise SkypeError(0, 'Seen can only be set to True')

    Seen = property(fset=_SetSeen,
    doc="""Marks a missed chat message as seen. Accepts only True value.

    :type: bool

    :deprecated: Extremely unpythonic, use `MarkAsSeen` instead.
    """)

    def _GetSender(self):
        return User(self._Owner, self.FromHandle)

    Sender = property(_GetSender,
    doc="""Sender of the chat message.

    :type: `User`
    """)

    def _GetStatus(self):
        return str(self._Property('STATUS'))

    Status = property(_GetStatus,
    doc="""Status of the chat message.

    :type: `enums`.cms*
    """)

    def _GetTimestamp(self):
        return float(self._Property('TIMESTAMP'))

    Timestamp = property(_GetTimestamp,
    doc="""Chat message timestamp.

    :type: float

    :see: `Datetime`
    """)

    def _GetType(self):
        return str(self._Property('TYPE'))

    Type = property(_GetType,
    doc="""Type of chat message.

    :type: `enums`.cme*
    """)

    def _GetUsers(self):
        return UserCollection(self._Owner, split(self._Property('USERS')))

    Users = property(_GetUsers,
    doc="""Users added to the chat.

    :type: `UserCollection`
    """)


class ChatMessageCollection(CachedCollection):
    _CachedType = ChatMessage


class ChatMember(Cached):
    """Represents a member of a public chat.
    """
    _ValidateHandle = int

    def __repr__(self):
        return Cached.__repr__(self, 'Id')

    def _Alter(self, AlterName, Args=None):
        return self._Owner._Alter('CHATMEMBER', self.Id, AlterName, Args,
                                  'ALTER CHATMEMBER %s %s' % (self.Id, AlterName))

    def _Property(self, PropName, Value=None, Cache=True):
        return self._Owner._Property('CHATMEMBER', self.Id, PropName, Value, Cache)

    def CanSetRoleTo(self, Role):
        """Checks if the new role can be applied to the member.

        :Parameters:
          Role : `enums`.chatMemberRole*
            New chat member role.

        :return: True if the new role can be applied, False otherwise.
        :rtype: bool
        """
        t = self._Owner._Alter('CHATMEMBER', self.Id, 'CANSETROLETO', Role,
                               'ALTER CHATMEMBER CANSETROLETO')
        return (chop(t, 1)[-1] == 'TRUE')

    def _GetChat(self):
        return Chat(self._Owner, self._Property('CHATNAME'))

    Chat = property(_GetChat,
    doc="""Chat this member belongs to.

    :type: `Chat`
    """)

    def _GetHandle(self):
        return str(self._Property('IDENTITY'))

    Handle = property(_GetHandle,
    doc="""Member Skypename.

    :type: str
    """)

    def _GetId(self):
        return self._Handle

    Id = property(_GetId,
    doc="""Chat member Id.

    :type: int
    """)

    def _GetIsActive(self):
        return (self._Property('IS_ACTIVE') == 'TRUE')

    IsActive = property(_GetIsActive,
    doc="""Member activity status.

    :type: bool
    """)

    def _GetRole(self):
        return str(self._Property('ROLE'))

    def _SetRole(self, Value):
        self._Alter('SETROLETO', Value)

    Role = property(_GetRole, _SetRole,
    doc="""Chat Member role.

    :type: `enums`.chatMemberRole*
    """)


class ChatMemberCollection(CachedCollection):
    _CachedType = ChatMember



apiAttachAvailable = u'API\u53ef\u4f9b\u4f7f\u7528'
apiAttachNotAvailable = u'\u4e0d\u4f9b\u4f7f\u7528'
apiAttachPendingAuthorization = u'\u5f85\u6388\u6743'
apiAttachRefused = u'\u62d2\u7edd'
apiAttachSuccess = u'\u6210\u529f'
apiAttachUnknown = u'\u4e0d\u8be6'
budDeletedFriend = u'\u5df2\u4ece\u670b\u53cb\u540d\u5355\u4e2d\u5220\u9664'
budFriend = u'\u670b\u53cb'
budNeverBeenFriend = u'\u4ece\u672a\u52a0\u5165\u670b\u53cb\u540d\u5355'
budPendingAuthorization = u'\u5f85\u6388\u6743'
budUnknown = u'\u4e0d\u8be6'
cfrBlockedByRecipient = u'\u901a\u8bdd\u88ab\u63a5\u6536\u65b9\u5c01\u9501'
cfrMiscError = u'\u5176\u5b83\u7c7b\u9519\u8bef'
cfrNoCommonCodec = u'\u65e0\u5e38\u89c1\u7f16\u89e3\u7801\u5668'
cfrNoProxyFound = u'\u627e\u4e0d\u5230\u4ee3\u7406\u670d\u52a1\u5668'
cfrNotAuthorizedByRecipient = u'\u5f53\u524d\u7528\u6237\u672a\u7ecf\u63a5\u6536\u65b9\u6388\u6743'
cfrRecipientNotFriend = u'\u63a5\u6536\u65b9\u4e0d\u662f\u670b\u53cb\u3002'
cfrRemoteDeviceError = u'\u8fdc\u7a0b\u58f0\u97f3\u8bbe\u5907\u9519\u8bef'
cfrSessionTerminated = u'\u4f1a\u8bdd\u7ed3\u675f'
cfrSoundIOError = u'\u97f3\u54cd\u8f93\u5165/\u8f93\u51fa\u9519\u8bef'
cfrSoundRecordingError = u'\u97f3\u54cd\u5f55\u97f3\u9519\u8bef'
cfrUnknown = u'\u4e0d\u8be6'
cfrUserDoesNotExist = u'\u7528\u6237/\u7535\u8bdd\u53f7\u7801\u4e0d\u5b58\u5728'
cfrUserIsOffline = u'\u5979\u6216\u4ed6\u5904\u4e8e\u8131\u673a\u72b6\u6001'
chsAllCalls = u'\u65e7\u7248\u5bf9\u8bdd'
chsDialog = u'\u5bf9\u8bdd'
chsIncomingCalls = u'\u591a\u4eba\u5bf9\u8bdd\u5f85\u63a5\u53d7'
chsLegacyDialog = u'\u65e7\u7248\u5bf9\u8bdd'
chsMissedCalls = u'\u5bf9\u8bdd'
chsMultiNeedAccept = u'\u591a\u4eba\u5bf9\u8bdd\u5f85\u63a5\u53d7'
chsMultiSubscribed = u'\u591a\u4eba\u52a0\u5165'
chsOutgoingCalls = u'\u591a\u4eba\u52a0\u5165'
chsUnknown = u'\u4e0d\u8be6'
chsUnsubscribed = u'\u5df2\u9000\u51fa'
clsBusy = u'\u5fd9'
clsCancelled = u'\u5df2\u53d6\u6d88'
clsEarlyMedia = u'\u6b63\u5728\u64ad\u653e\u65e9\u671f\u4fe1\u53f7\uff08Early Media\uff09'
clsFailed = u'\u5bf9\u4e0d\u8d77\uff0c\u547c\u53eb\u5931\u8d25\uff01'
clsFinished = u'\u5b8c\u6bd5'
clsInProgress = u'\u6b63\u5728\u8fdb\u884c\u901a\u8bdd'
clsLocalHold = u'\u672c\u65b9\u6682\u5019'
clsMissed = u'\u4e2a\u672a\u5e94\u7b54\u547c\u53eb'
clsOnHold = u'\u4fdd\u6301'
clsRefused = u'\u62d2\u7edd'
clsRemoteHold = u'\u5bf9\u65b9\u6682\u5019'
clsRinging = u'\u547c\u53eb'
clsRouting = u'\u6b63\u5728\u63a5\u901a'
clsTransferred = u'\u4e0d\u8be6'
clsTransferring = u'\u4e0d\u8be6'
clsUnknown = u'\u4e0d\u8be6'
clsUnplaced = u'\u4ece\u672a\u62e8\u6253'
clsVoicemailBufferingGreeting = u'\u6b63\u5728\u51c6\u5907\u95ee\u5019\u8bed'
clsVoicemailCancelled = u'\u8bed\u97f3\u7559\u8a00\u5df2\u53d6\u6d88'
clsVoicemailFailed = u'\u8bed\u97f3\u90ae\u4ef6\u5931\u8d25'
clsVoicemailPlayingGreeting = u'\u6b63\u5728\u64ad\u653e\u95ee\u5019\u8bed'
clsVoicemailRecording = u'\u5f55\u5236\u8bed\u97f3\u90ae\u4ef6'
clsVoicemailSent = u'\u8bed\u97f3\u7559\u8a00\u5df2\u53d1\u9001'
clsVoicemailUploading = u'\u6b63\u5728\u4e0a\u8f7d\u8bed\u97f3\u7559\u8a00'
cltIncomingP2P = u'\u62e8\u5165\u5bf9\u7b49\u7535\u8bdd'
cltIncomingPSTN = u'\u62e8\u5165\u7535\u8bdd'
cltOutgoingP2P = u'\u62e8\u51fa\u5bf9\u7b49\u7535\u8bdd'
cltOutgoingPSTN = u'\u62e8\u51fa\u7535\u8bdd'
cltUnknown = u'\u4e0d\u8be6'
cmeAddedMembers = u'\u6240\u6dfb\u6210\u5458'
cmeCreatedChatWith = u'\u66fe\u4e0e\u6b64\u4eba\u804a\u5929'
cmeEmoted = u'\u4e0d\u8be6'
cmeLeft = u'\u79bb\u5f00'
cmeSaid = u'\u5df2\u8bf4\u8fc7'
cmeSawMembers = u'\u770b\u5230\u6210\u5458'
cmeSetTopic = u'\u8bbe\u5b9a\u4e3b\u9898'
cmeUnknown = u'\u4e0d\u8be6'
cmsRead = u'\u5df2\u8bfb\u53d6'
cmsReceived = u'\u5df2\u63a5\u6536'
cmsSending = u'\u6b63\u5728\u53d1\u9001...'
cmsSent = u'\u5df2\u53d1\u9001'
cmsUnknown = u'\u4e0d\u8be6'
conConnecting = u'\u6b63\u5728\u8fde\u63a5'
conOffline = u'\u8131\u673a'
conOnline = u'\u8054\u673a'
conPausing = u'\u6682\u505c\u4e2d'
conUnknown = u'\u4e0d\u8be6'
cusAway = u'\u79bb\u5f00'
cusDoNotDisturb = u'\u8bf7\u52ff\u6253\u6270'
cusInvisible = u'\u9690\u8eab'
cusLoggedOut = u'\u8131\u673a'
cusNotAvailable = u'\u4e0d\u4f9b\u4f7f\u7528'
cusOffline = u'\u8131\u673a'
cusOnline = u'\u8054\u673a'
cusSkypeMe = u'Skype Me'
cusUnknown = u'\u4e0d\u8be6'
cvsBothEnabled = u'\u89c6\u9891\u53d1\u9001\u548c\u63a5\u6536'
cvsNone = u'\u65e0\u89c6\u9891'
cvsReceiveEnabled = u'\u89c6\u9891\u63a5\u6536'
cvsSendEnabled = u'\u89c6\u9891\u53d1\u9001'
cvsUnknown = u''
grpAllFriends = u'\u6240\u6709\u670b\u53cb'
grpAllUsers = u'\u6240\u6709\u7528\u6237'
grpCustomGroup = u'\u81ea\u5b9a\u4e49'
grpOnlineFriends = u'\u8054\u673a\u670b\u53cb'
grpPendingAuthorizationFriends = u'\u5f85\u6388\u6743'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'\u6700\u8fd1\u8054\u7cfb\u8fc7\u7684\u7528\u6237'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype\u670b\u53cb'
grpSkypeOutFriends = u'SkypeOut\u670b\u53cb'
grpUngroupedFriends = u'\u672a\u5206\u7ec4\u7684\u670b\u53cb'
grpUnknown = u'\u4e0d\u8be6'
grpUsersAuthorizedByMe = u'\u7ecf\u6211\u6388\u6743'
grpUsersBlockedByMe = u'\u88ab\u6211\u5c01\u9501'
grpUsersWaitingMyAuthorization = u'\u6b63\u7b49\u5f85\u6211\u7684\u6388\u6743'
leaAddDeclined = u'\u6dfb\u52a0\u906d\u62d2'
leaAddedNotAuthorized = u'\u88ab\u6dfb\u52a0\u4eba\u987b\u7ecf\u6388\u6743'
leaAdderNotFriend = u'\u6dfb\u52a0\u4eba\u987b\u4e3a\u670b\u53cb'
leaUnknown = u'\u4e0d\u8be6'
leaUnsubscribe = u'\u5df2\u9000\u51fa'
leaUserIncapable = u'\u7528\u6237\u4e0d\u80fd\u4f7f\u7528'
leaUserNotFound = u'\u7528\u6237\u672a\u627e\u5230'
olsAway = u'\u79bb\u5f00'
olsDoNotDisturb = u'\u8bf7\u52ff\u6253\u6270'
olsNotAvailable = u'\u4e0d\u4f9b\u4f7f\u7528'
olsOffline = u'\u8131\u673a'
olsOnline = u'\u8054\u673a'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'\u4e0d\u8be6'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'\u5973'
usexMale = u'\u7537'
usexUnknown = u'\u4e0d\u8be6'
vmrConnectError = u'\u8fde\u63a5\u9519\u8bef'
vmrFileReadError = u'\u6587\u4ef6\u8bfb\u53d6\u9519\u8bef'
vmrFileWriteError = u'\u6587\u4ef6\u5199\u5165\u9519\u8bef'
vmrMiscError = u'\u5176\u5b83\u7c7b\u9519\u8bef'
vmrNoError = u'\u65e0\u9519\u8bef'
vmrNoPrivilege = u'\u65e0\u4f7f\u7528\u8bed\u97f3\u7559\u8a00\u6743\u9650'
vmrNoVoicemail = u'\u4e0d\u5b58\u5728\u8be5\u8bed\u97f3\u7559\u8a00'
vmrPlaybackError = u'\u64ad\u653e\u9519\u8bef'
vmrRecordingError = u'\u5f55\u97f3\u9519\u8bef'
vmrUnknown = u'\u4e0d\u8be6'
vmsBlank = u'\u7a7a\u767d\u7559\u8a00'
vmsBuffering = u'\u6b63\u5728\u7f13\u51b2'
vmsDeleting = u'\u6b63\u5728\u5220\u9664'
vmsDownloading = u'\u6b63\u5728\u4e0b\u8f7d'
vmsFailed = u'\u5931\u8d25'
vmsNotDownloaded = u'\u672a\u4e0b\u8f7d'
vmsPlayed = u'\u5df2\u64ad\u653e\u7559\u8a00'
vmsPlaying = u'\u6b63\u5728\u64ad\u653e'
vmsRecorded = u'\u5df2\u5f55\u97f3\u7559\u8a00'
vmsRecording = u'\u5f55\u5236\u8bed\u97f3\u90ae\u4ef6'
vmsUnknown = u'\u4e0d\u8be6'
vmsUnplayed = u'\u672a\u64ad\u653e\u7684\u7559\u8a00'
vmsUploaded = u'\u4e0a\u8f7d\u5b8c\u6bd5'
vmsUploading = u'\u6b63\u5728\u4e0a\u8f7d'
vmtCustomGreeting = u'\u81ea\u5b9a\u4e49\u95ee\u5019\u8bed'
vmtDefaultGreeting = u'\u9ed8\u8ba4\u95ee\u5019\u8bed'
vmtIncoming = u'\u63a5\u6536\u8bed\u97f3\u90ae\u4ef6'
vmtOutgoing = u'\u5916\u51fa'
vmtUnknown = u'\u4e0d\u8be6'
vssAvailable = u'\u53ef\u4f9b\u4f7f\u7528'
vssNotAvailable = u'\u4e0d\u4f9b\u4f7f\u7528'
vssPaused = u'\u6682\u505c'
vssRejected = u'\u62d2\u7edd\u53d7\u8bdd'
vssRunning = u'\u8fd0\u884c\u4e2d'
vssStarting = u'\u5f00\u59cb'
vssStopping = u'\u505c\u6b62\u4e2d'
vssUnknown = u'\u4e0d\u8be6'



apiAttachAvailable = u'API forefindes'
apiAttachNotAvailable = u'Optaget'
apiAttachPendingAuthorization = u'Afventer godkendelse'
apiAttachRefused = u'Afvist'
apiAttachSuccess = u'Succes'
apiAttachUnknown = u'Ukendt'
budDeletedFriend = u'Slettet fra liste over kontaktpersoner'
budFriend = u'Ven'
budNeverBeenFriend = u'Aldrig v\xe6ret p\xe5 liste over kontaktpersoner'
budPendingAuthorization = u'Afventer godkendelse'
budUnknown = u'Ukendt'
cfrBlockedByRecipient = u'Opkald blokeret af modtager'
cfrMiscError = u'Anden fejl'
cfrNoCommonCodec = u'Intet f\xe6lles codec fundet'
cfrNoProxyFound = u'Ingen proxy fundet'
cfrNotAuthorizedByRecipient = u'Aktuel bruger er ikke godkendt af modtager'
cfrRecipientNotFriend = u'Modtager er ikke en ven'
cfrRemoteDeviceError = u'Problem med lydenhed hos modparten'
cfrSessionTerminated = u'Session afsluttet'
cfrSoundIOError = u'Lyd-I/O fejl'
cfrSoundRecordingError = u'Lydoptagelsesfejl'
cfrUnknown = u'Ukendt'
cfrUserDoesNotExist = u'Bruger/telefonnummer findes ikke'
cfrUserIsOffline = u'Han eller hun er offline'
chsAllCalls = u'Dialog med tidligere version'
chsDialog = u'Dialog'
chsIncomingCalls = u'Behov for \xa0accept af flere brugere'
chsLegacyDialog = u'Dialog med tidligere version'
chsMissedCalls = u'Dialog'
chsMultiNeedAccept = u'Behov for \xa0accept af flere brugere'
chsMultiSubscribed = u'Flere brugere deltager'
chsOutgoingCalls = u'Flere brugere deltager'
chsUnknown = u'Ukendt'
chsUnsubscribed = u'Afmeldt'
clsBusy = u'Optaget'
clsCancelled = u'Afbrudt'
clsEarlyMedia = u'Afspiller startmedier (Early Media)'
clsFailed = u'Opkaldet mislykkedes!'
clsFinished = u'Afsluttet'
clsInProgress = u'udf\xf8rer'
clsLocalHold = u'Opkald parkeret (lokalt)'
clsMissed = u'Mistet opkald'
clsOnHold = u'Parkeret'
clsRefused = u'Afvist'
clsRemoteHold = u'Opkald parkeret (fjernsystem)'
clsRinging = u'ringer'
clsRouting = u'Omdirigerer'
clsTransferred = u'Ukendt'
clsTransferring = u'Ukendt'
clsUnknown = u'Ukendt'
clsUnplaced = u'Aldrig foretaget'
clsVoicemailBufferingGreeting = u'Bufferlagring af besked'
clsVoicemailCancelled = u'Stemmebesked er afbrudt'
clsVoicemailFailed = u'Stemmebesked fejlet'
clsVoicemailPlayingGreeting = u'Afspiller besked'
clsVoicemailRecording = u'Optager stemmebesked'
clsVoicemailSent = u'Stemmebesked er afsendt'
clsVoicemailUploading = u'Overf\xf8rer stemmebesked'
cltIncomingP2P = u'Indg\xe5ende peer-to-peer-opkald'
cltIncomingPSTN = u'Indg\xe5ende telefonopkald'
cltOutgoingP2P = u'Udg\xe5ende peer-to-peer-opkald'
cltOutgoingPSTN = u'Udg\xe5ende telefonopkald'
cltUnknown = u'Ukendt'
cmeAddedMembers = u'Tilf\xf8jede medlemmer'
cmeCreatedChatWith = u'Oprettet chat med'
cmeEmoted = u'Ukendt'
cmeLeft = u'Forladt'
cmeSaid = u'Sagt'
cmeSawMembers = u'S\xe5 medlemmer'
cmeSetTopic = u'Angiv emne'
cmeUnknown = u'Ukendt'
cmsRead = u'L\xe6st'
cmsReceived = u'Modtaget'
cmsSending = u'Sender...'
cmsSent = u'Sendt'
cmsUnknown = u'Ukendt'
conConnecting = u'Tilslutter'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'Midlertidigt afbrudt'
conUnknown = u'Ukendt'
cusAway = u'Ikke til stede'
cusDoNotDisturb = u'Vil ikke forstyrres'
cusInvisible = u'Usynlig'
cusLoggedOut = u'Offline'
cusNotAvailable = u'Optaget'
cusOffline = u'Offline'
cusOnline = u'Online'
cusSkypeMe = u'Ring til mig'
cusUnknown = u'Ukendt'
cvsBothEnabled = u'Video send og modtag'
cvsNone = u'Ingen video'
cvsReceiveEnabled = u'Video modtag'
cvsSendEnabled = u'Video send'
cvsUnknown = u''
grpAllFriends = u'Alle venner'
grpAllUsers = u'Alle brugere'
grpCustomGroup = u'Tilpasset'
grpOnlineFriends = u'Online-venner'
grpPendingAuthorizationFriends = u'Afventer godkendelse'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Venner kontaktet for nylig'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-venner'
grpSkypeOutFriends = u'SkypeOut-venner'
grpUngroupedFriends = u'Ikke-grupperede venner'
grpUnknown = u'Ukendt'
grpUsersAuthorizedByMe = u'Godkendt af mig'
grpUsersBlockedByMe = u'Blokeret af mig'
grpUsersWaitingMyAuthorization = u'Afventer min godkendelse'
leaAddDeclined = u'Tilf\xf8jelse afvist'
leaAddedNotAuthorized = u'Tilf\xf8jet skal v\xe6re godkendt'
leaAdderNotFriend = u'Tilf\xf8jet skal v\xe6re ven'
leaUnknown = u'Ukendt'
leaUnsubscribe = u'Afmeldt'
leaUserIncapable = u'Bruger kan ikke forts\xe6tte'
leaUserNotFound = u'Bruger ikke fundet'
olsAway = u'Ikke til stede'
olsDoNotDisturb = u'Vil ikke forstyrres'
olsNotAvailable = u'Optaget'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'Ring til mig'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Ukendt'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Kvinde'
usexMale = u'Mand'
usexUnknown = u'Ukendt'
vmrConnectError = u'Fejl ved forbindelse'
vmrFileReadError = u'Der opstod en fejl under l\xe6sning af filen'
vmrFileWriteError = u'Der opstod en fejl under lagring af filen'
vmrMiscError = u'Anden fejl'
vmrNoError = u'Ingen fejl'
vmrNoPrivilege = u'Du kan ikke l\xe6gge en stemmebesked'
vmrNoVoicemail = u'Stemmebeskeden findes ikke'
vmrPlaybackError = u'Afspilningsfejl'
vmrRecordingError = u'Indspilningsfejl'
vmrUnknown = u'Ukendt'
vmsBlank = u'Blank'
vmsBuffering = u'Bufferlagrer'
vmsDeleting = u'Sletter'
vmsDownloading = u'Henter'
vmsFailed = u'Mislykkedes'
vmsNotDownloaded = u'Ikke hentet'
vmsPlayed = u'Afspillet'
vmsPlaying = u'Afspiller'
vmsRecorded = u'Optaget'
vmsRecording = u'Optager stemmebesked'
vmsUnknown = u'Ukendt'
vmsUnplayed = u'Ikke afspillet'
vmsUploaded = u'Overf\xf8rt'
vmsUploading = u'Overf\xf8rer'
vmtCustomGreeting = u'Tilpasset besked'
vmtDefaultGreeting = u'Standardbesked'
vmtIncoming = u'indg\xe5ende voicemail'
vmtOutgoing = u'Udg\xe5ende'
vmtUnknown = u'Ukendt'
vssAvailable = u'Ledig'
vssNotAvailable = u'Optaget'
vssPaused = u'Midlertidigt afbrudt'
vssRejected = u'Afvist'
vssRunning = u'K\xf8rer'
vssStarting = u'Starter'
vssStopping = u'Stopper'
vssUnknown = u'Ukendt'



apiAttachAvailable = u'API Kullanilabilir'
apiAttachNotAvailable = u'Kullanilamiyor'
apiAttachPendingAuthorization = u'Yetkilendirme Bekliyor'
apiAttachRefused = u'Reddedildi'
apiAttachSuccess = u'Basarili oldu'
apiAttachUnknown = u'Bilinmiyor'
budDeletedFriend = u'Arkadas Listesinden Silindi'
budFriend = u'Arkadas'
budNeverBeenFriend = u'Arkadas Listesinde Hi\xe7 Olmadi'
budPendingAuthorization = u'Yetkilendirme Bekliyor'
budUnknown = u'Bilinmiyor'
cfrBlockedByRecipient = u'\xc7agri alici tarafindan engellendi'
cfrMiscError = u'Diger Hata'
cfrNoCommonCodec = u'Genel codec yok'
cfrNoProxyFound = u'Proxy bulunamadi'
cfrNotAuthorizedByRecipient = u'Ge\xe7erli kullanici alici tarafindan yetkilendirilmemis'
cfrRecipientNotFriend = u'Alici bir arkadas degil'
cfrRemoteDeviceError = u'Uzak ses aygitinda problem var'
cfrSessionTerminated = u'Oturum sonlandirildi'
cfrSoundIOError = u'Ses G/\xc7 hatasi'
cfrSoundRecordingError = u'Ses kayit hatasi'
cfrUnknown = u'Bilinmiyor'
cfrUserDoesNotExist = u'Kullanici/telefon numarasi mevcut degil'
cfrUserIsOffline = u'\xc7evrim Disi'
chsAllCalls = u'Eski Diyalog'
chsDialog = u'Diyalog'
chsIncomingCalls = u'\xc7oklu Sohbet Kabul\xfc Gerekli'
chsLegacyDialog = u'Eski Diyalog'
chsMissedCalls = u'Diyalog'
chsMultiNeedAccept = u'\xc7oklu Sohbet Kabul\xfc Gerekli'
chsMultiSubscribed = u'\xc7oklu Abonelik'
chsOutgoingCalls = u'\xc7oklu Abonelik'
chsUnknown = u'Bilinmiyor'
chsUnsubscribed = u'Aboneligi Silindi'
clsBusy = u'Mesgul'
clsCancelled = u'Iptal Edildi'
clsEarlyMedia = u'Early Media y\xfcr\xfct\xfcl\xfcyor'
clsFailed = u'\xdczg\xfcn\xfcz, arama basarisiz!'
clsFinished = u'Bitirildi'
clsInProgress = u'Arama Yapiliyor'
clsLocalHold = u'Yerel Beklemede'
clsMissed = u'Cevapsiz Arama'
clsOnHold = u'Beklemede'
clsRefused = u'Reddedildi'
clsRemoteHold = u'Uzak Beklemede'
clsRinging = u'ariyor'
clsRouting = u'Y\xf6nlendirme'
clsTransferred = u'Bilinmiyor'
clsTransferring = u'Bilinmiyor'
clsUnknown = u'Bilinmiyor'
clsUnplaced = u'Asla baglanmadi'
clsVoicemailBufferingGreeting = u'Selamlama Ara Bellege Aliniyor'
clsVoicemailCancelled = u'Sesli Posta Iptal Edildi'
clsVoicemailFailed = u'Sesli Mesaj Basarisiz'
clsVoicemailPlayingGreeting = u'Selamlama Y\xfcr\xfct\xfcl\xfcyor'
clsVoicemailRecording = u'Sesli Mesaj Kaydediliyor'
clsVoicemailSent = u'Sesli Posta G\xf6nderildi'
clsVoicemailUploading = u'Sesli Posta Karsiya Y\xfckleniyor'
cltIncomingP2P = u'Gelen Esler Arasi Telefon \xc7agrisi'
cltIncomingPSTN = u'Gelen Telefon \xc7agrisi'
cltOutgoingP2P = u'Giden Esler Arasi Telefon \xc7agrisi'
cltOutgoingPSTN = u'Giden Telefon \xc7agrisi'
cltUnknown = u'Bilinmiyor'
cmeAddedMembers = u'Eklenen \xdcyeler'
cmeCreatedChatWith = u'Sohbet Olusturuldu:'
cmeEmoted = u'Bilinmiyor'
cmeLeft = u'Birakilan'
cmeSaid = u'Ifade'
cmeSawMembers = u'G\xf6r\xfclen \xdcyeler'
cmeSetTopic = u'Konu Belirleme'
cmeUnknown = u'Bilinmiyor'
cmsRead = u'Okundu'
cmsReceived = u'Alindi'
cmsSending = u'G\xf6nderiliyor...'
cmsSent = u'G\xf6nderildi'
cmsUnknown = u'Bilinmiyor'
conConnecting = u'Baglaniyor'
conOffline = u'\xc7evrim Disi'
conOnline = u'\xc7evrim I\xe7i'
conPausing = u'Duraklatiliyor'
conUnknown = u'Bilinmiyor'
cusAway = u'Uzakta'
cusDoNotDisturb = u'Rahatsiz Etmeyin'
cusInvisible = u'G\xf6r\xfcnmez'
cusLoggedOut = u'\xc7evrim Disi'
cusNotAvailable = u'Kullanilamiyor'
cusOffline = u'\xc7evrim Disi'
cusOnline = u'\xc7evrim I\xe7i'
cusSkypeMe = u'Skype Me'
cusUnknown = u'Bilinmiyor'
cvsBothEnabled = u'Video G\xf6nderme ve Alma'
cvsNone = u'Video Yok'
cvsReceiveEnabled = u'Video Alma'
cvsSendEnabled = u'Video G\xf6nderme'
cvsUnknown = u''
grpAllFriends = u'T\xfcm Arkadaslar'
grpAllUsers = u'T\xfcm Kullanicilar'
grpCustomGroup = u'\xd6zel'
grpOnlineFriends = u'\xc7evrimi\xe7i Arkadaslar'
grpPendingAuthorizationFriends = u'Yetkilendirme Bekliyor'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'Son Zamanlarda Iletisim Kurulmus Kullanicilar'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype Arkadaslari'
grpSkypeOutFriends = u'SkypeOut Arkadaslari'
grpUngroupedFriends = u'Gruplanmamis Arkadaslar'
grpUnknown = u'Bilinmiyor'
grpUsersAuthorizedByMe = u'Tarafimdan Yetkilendirilenler'
grpUsersBlockedByMe = u'Engellediklerim'
grpUsersWaitingMyAuthorization = u'Yetkilendirmemi Bekleyenler'
leaAddDeclined = u'Ekleme Reddedildi'
leaAddedNotAuthorized = u'Ekleyen Kisinin Yetkisi Olmali'
leaAdderNotFriend = u'Ekleyen Bir Arkadas Olmali'
leaUnknown = u'Bilinmiyor'
leaUnsubscribe = u'Aboneligi Silindi'
leaUserIncapable = u'Kullanicidan Kaynaklanan Yetersizlik'
leaUserNotFound = u'Kullanici Bulunamadi'
olsAway = u'Uzakta'
olsDoNotDisturb = u'Rahatsiz Etmeyin'
olsNotAvailable = u'Kullanilamiyor'
olsOffline = u'\xc7evrim Disi'
olsOnline = u'\xc7evrim I\xe7i'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Bilinmiyor'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Kadin'
usexMale = u'Erkek'
usexUnknown = u'Bilinmiyor'
vmrConnectError = u'Baglanti Hatasi'
vmrFileReadError = u'Dosya Okuma Hatasi'
vmrFileWriteError = u'Dosya Yazma Hatasi'
vmrMiscError = u'Diger Hata'
vmrNoError = u'Hata Yok'
vmrNoPrivilege = u'Sesli Posta \xd6nceligi Yok'
vmrNoVoicemail = u'B\xf6yle Bir Sesli Posta Yok'
vmrPlaybackError = u'Y\xfcr\xfctme Hatasi'
vmrRecordingError = u'Kayit Hatasi'
vmrUnknown = u'Bilinmiyor'
vmsBlank = u'Bos'
vmsBuffering = u'Ara bellege aliniyor'
vmsDeleting = u'Siliniyor'
vmsDownloading = u'Karsidan Y\xfckleniyor'
vmsFailed = u'Basarisiz Oldu'
vmsNotDownloaded = u'Karsidan Y\xfcklenmedi'
vmsPlayed = u'Y\xfcr\xfct\xfcld\xfc'
vmsPlaying = u'Y\xfcr\xfct\xfcl\xfcyor'
vmsRecorded = u'Kaydedildi'
vmsRecording = u'Sesli Mesaj Kaydediliyor'
vmsUnknown = u'Bilinmiyor'
vmsUnplayed = u'Y\xfcr\xfct\xfclmemis'
vmsUploaded = u'Karsiya Y\xfcklendi'
vmsUploading = u'Karsiya Y\xfckleniyor'
vmtCustomGreeting = u'\xd6zel Selamlama'
vmtDefaultGreeting = u'Varsayilan Selamlama'
vmtIncoming = u'gelen sesli mesaj'
vmtOutgoing = u'Giden'
vmtUnknown = u'Bilinmiyor'
vssAvailable = u'Kullanilabilir'
vssNotAvailable = u'Kullanilamiyor'
vssPaused = u'Duraklatildi'
vssRejected = u'Reddedildi'
vssRunning = u'\xc7alisiyor'
vssStarting = u'Basliyor'
vssStopping = u'Durduruluyor'
vssUnknown = u'Bilinmiyor'



"""Current user profile.
"""
__docformat__ = 'restructuredtext en'


import weakref

from utils import *


class Profile(object):
    """Represents the profile of currently logged in user. Access using
    `skype.Skype.CurrentUserProfile`.
    """

    def __init__(self, Skype):
        """__init__.

        :Parameters:
          Skype : `Skype`
            Skype object.
        """
        self._SkypeRef = weakref.ref(Skype)

    def _Property(self, PropName, Set=None):
        return self._Skype._Property('PROFILE', '', PropName, Set)

    def _Get_Skype(self):
        skype = self._SkypeRef()
        if skype:
            return skype
        raise Exception()

    _Skype = property(_Get_Skype)

    def _GetAbout(self):
        return self._Property('ABOUT')

    def _SetAbout(self, Value):
        self._Property('ABOUT', Value)

    About = property(_GetAbout, _SetAbout,
    doc=""""About" field of the profile.

    :type: unicode
    """)

    def _GetBalance(self):
        return int(self._Property('PSTN_BALANCE'))

    Balance = property(_GetBalance,
    doc="""Skype credit balance. Note that the precision of profile balance value is currently
    fixed at 2 decimal places, regardless of currency or any other settings. Use `BalanceValue`
    to get the balance expressed in currency.

    :type: int

    :see: `BalanceCurrency`, `BalanceToText`, `BalanceValue`
    """)

    def _GetBalanceCurrency(self):
        return self._Property('PSTN_BALANCE_CURRENCY')

    BalanceCurrency = property(_GetBalanceCurrency,
    doc="""Skype credit balance currency.

    :type: unicode

    :see: `Balance`, `BalanceToText`, `BalanceValue`
    """)

    def _GetBalanceToText(self):
        return (u'%s %.2f' % (self.BalanceCurrency, self.BalanceValue)).strip()

    BalanceToText = property(_GetBalanceToText,
    doc="""Skype credit balance as properly formatted text with currency.

    :type: unicode

    :see: `Balance`, `BalanceCurrency`, `BalanceValue`
    """)

    def _GetBalanceValue(self):
        return float(self._Property('PSTN_BALANCE')) / 100

    BalanceValue = property(_GetBalanceValue,
    doc="""Skype credit balance expressed in currency.

    :type: float

    :see: `Balance`, `BalanceCurrency`, `BalanceToText`
    """)

    def _GetBirthday(self):
        value = self._Property('BIRTHDAY')
        if len(value) == 8:
            from datetime import date
            from time import strptime
            return date(*strptime(value, '%Y%m%d')[:3])

    def _SetBirthday(self, Value):
        if Value:
            self._Property('BIRTHDAY', Value.strftime('%Y%m%d'))
        else:
            self._Property('BIRTHDAY', 0)

    Birthday = property(_GetBirthday, _SetBirthday,
    doc=""""Birthday" field of the profile.

    :type: datetime.date
    """)

    def _GetCallApplyCF(self):
        return (self._Property('CALL_APPLY_CF') == 'TRUE')

    def _SetCallApplyCF(self, Value):
        self._Property('CALL_APPLY_CF', cndexp(Value, 'TRUE', 'FALSE'))

    CallApplyCF = property(_GetCallApplyCF, _SetCallApplyCF,
    doc="""Tells if call forwarding is enabled in the profile.

    :type: bool
    """)

    def _GetCallForwardRules(self):
        return str(self._Property('CALL_FORWARD_RULES'))

    def _SetCallForwardRules(self, Value):
        self._Property('CALL_FORWARD_RULES', Value)

    CallForwardRules = property(_GetCallForwardRules, _SetCallForwardRules,
    doc="""Call forwarding rules of the profile.

    :type: str
    """)

    def _GetCallNoAnswerTimeout(self):
        return int(self._Property('CALL_NOANSWER_TIMEOUT'))

    def _SetCallNoAnswerTimeout(self, Value):
        self._Property('CALL_NOANSWER_TIMEOUT', Value)

    CallNoAnswerTimeout = property(_GetCallNoAnswerTimeout, _SetCallNoAnswerTimeout,
    doc="""Number of seconds a call will ring without being answered before it
    stops ringing.

    :type: int
    """)

    def _GetCallSendToVM(self):
        return (self._Property('CALL_SEND_TO_VM') == 'TRUE')

    def _SetCallSendToVM(self, Value):
        self._Property('CALL_SEND_TO_VM', cndexp(Value, 'TRUE', 'FALSE'))

    CallSendToVM = property(_GetCallSendToVM, _SetCallSendToVM,
    doc="""Tells whether calls will be sent to the voicemail.

    :type: bool
    """)

    def _GetCity(self):
        return self._Property('CITY')

    def _SetCity(self, Value):
        self._Property('CITY', Value)

    City = property(_GetCity, _SetCity,
    doc=""""City" field of the profile.

    :type: unicode
    """)

    def _GetCountry(self):
        return chop(self._Property('COUNTRY'))[0]

    def _SetCountry(self, Value):
        self._Property('COUNTRY', Value)

    Country = property(_GetCountry, _SetCountry,
    doc=""""Country" field of the profile.

    :type: unicode
    """)

    def _GetFullName(self):
        return self._Property('FULLNAME')

    def _SetFullName(self, Value):
        self._Property('FULLNAME', Value)

    FullName = property(_GetFullName, _SetFullName,
    doc=""""Full name" field of the profile.

    :type: unicode
    """)

    def _GetHomepage(self):
        return self._Property('HOMEPAGE')

    def _SetHomepage(self, Value):
        self._Property('HOMEPAGE', Value)

    Homepage = property(_GetHomepage, _SetHomepage,
    doc=""""Homepage" field of the profile.

    :type: unicode
    """)

    def _GetIPCountry(self):
        return str(self._Property('IPCOUNTRY'))

    IPCountry = property(_GetIPCountry,
    doc="""ISO country code queried by IP address.

    :type: str
    """)

    def _GetLanguages(self):
        return [str(x) for x in split(self._Property('LANGUAGES'))]

    def _SetLanguages(self, Value):
        self._Property('LANGUAGES', ' '.join(Value))

    Languages = property(_GetLanguages, _SetLanguages,
    doc=""""ISO language codes of the profile.

    :type: list of str
    """)

    def _GetMoodText(self):
        return self._Property('MOOD_TEXT')

    def _SetMoodText(self, Value):
        self._Property('MOOD_TEXT', Value)

    MoodText = property(_GetMoodText, _SetMoodText,
    doc=""""Mood text" field of the profile.

    :type: unicode
    """)

    def _GetPhoneHome(self):
        return self._Property('PHONE_HOME')

    def _SetPhoneHome(self, Value):
        self._Property('PHONE_HOME', Value)

    PhoneHome = property(_GetPhoneHome, _SetPhoneHome,
    doc=""""Phone home" field of the profile.

    :type: unicode
    """)

    def _GetPhoneMobile(self):
        return self._Property('PHONE_MOBILE')

    def _SetPhoneMobile(self, Value):
        self._Property('PHONE_MOBILE', Value)

    PhoneMobile = property(_GetPhoneMobile, _SetPhoneMobile,
    doc=""""Phone mobile" field of the profile.

    :type: unicode
    """)

    def _GetPhoneOffice(self):
        return self._Property('PHONE_OFFICE')

    def _SetPhoneOffice(self, Value):
        self._Property('PHONE_OFFICE', Value)

    PhoneOffice = property(_GetPhoneOffice, _SetPhoneOffice,
    doc=""""Phone office" field of the profile.

    :type: unicode
    """)

    def _GetProvince(self):
        return self._Property('PROVINCE')

    def _SetProvince(self, Value):
        self._Property('PROVINCE', Value)

    Province = property(_GetProvince, _SetProvince,
    doc=""""Province" field of the profile.

    :type: unicode
    """)

    def _GetRichMoodText(self):
        return self._Property('RICH_MOOD_TEXT')

    def _SetRichMoodText(self, Value):
        self._Property('RICH_MOOD_TEXT', Value)

    RichMoodText = property(_GetRichMoodText, _SetRichMoodText,
    doc="""Rich mood text of the profile.

    :type: unicode

    :see: https://developer.skype.com/Docs/ApiDoc/SET_PROFILE_RICH_MOOD_TEXT
    """)

    def _GetSex(self):
        return str(self._Property('SEX'))

    def _SetSex(self, Value):
        self._Property('SEX', Value)

    Sex = property(_GetSex, _SetSex,
    doc=""""Sex" field of the profile.

    :type: `enums`.usex*
    """)

    def _GetTimezone(self):
        return int(self._Property('TIMEZONE'))

    def _SetTimezone(self, Value):
        self._Property('TIMEZONE', Value)

    Timezone = property(_GetTimezone, _SetTimezone,
    doc="""Timezone of the current profile in minutes from GMT.

    :type: int
    """)

    def _GetValidatedSmsNumbers(self):
        return [str(x) for x in split(self._Property('SMS_VALIDATED_NUMBERS'), ', ')]

    ValidatedSmsNumbers = property(_GetValidatedSmsNumbers,
    doc="""List of phone numbers the user has registered for usage in reply-to
    field of SMS messages.

    :type: list of str
    """)



apiAttachAvailable = u'API\u304c\u898b\u3064\u304b\u308a\u307e\u3057\u305f'
apiAttachNotAvailable = u'\u7121\u52b9'
apiAttachPendingAuthorization = u'\u8a8d\u8a3c\u5f85\u3061'
apiAttachRefused = u'\u62d2\u5426\u3055\u308c\u307e\u3057\u305f'
apiAttachSuccess = u'\u6210\u529f'
apiAttachUnknown = u'\u4e0d\u660e'
budDeletedFriend = u'\u53cb\u4eba\u30ea\u30b9\u30c8\u304b\u3089\u524a\u9664\u3055\u308c\u307e\u3057\u305f'
budFriend = u'\u53cb\u4eba'
budNeverBeenFriend = u'\u53cb\u4eba\u30ea\u30b9\u30c8\u306b\u672a\u8ffd\u52a0'
budPendingAuthorization = u'\u8a8d\u8a3c\u5f85\u3061'
budUnknown = u'\u4e0d\u660e'
cfrBlockedByRecipient = u'\u76f8\u624b\u306b\u901a\u8a71\u304c\u30d6\u30ed\u30c3\u30af\u3055\u308c\u307e\u3057\u305f'
cfrMiscError = u'\u305d\u306e\u4ed6\u30a8\u30e9\u30fc'
cfrNoCommonCodec = u'\u4e00\u822c\u7684\u306a\u30b3\u30fc\u30c7\u30c3\u30af\u3067\u306f\u3042\u308a\u307e\u305b\u3093'
cfrNoProxyFound = u'\u30d7\u30ed\u30ad\u30b7\u304c\u898b\u3064\u304b\u308a\u307e\u305b\u3093'
cfrNotAuthorizedByRecipient = u'\u30e6\u30fc\u30b6\u304c\u53d7\u4fe1\u8005\u306b\u8a8d\u8a3c\u3055\u308c\u3066\u3044\u308b\u5fc5\u8981\u304c\u3042\u308a\u307e\u3059\u3002'
cfrRecipientNotFriend = u'\u53d7\u4fe1\u8005\u306f\u53cb\u4eba\u3068\u3057\u3066\u767b\u9332\u3055\u308c\u3066\u3044\u307e\u305b\u3093'
cfrRemoteDeviceError = u'\u30ea\u30e2\u30fc\u30c8\u30aa\u30fc\u30c7\u30a3\u30aa\u30c7\u30d0\u30a4\u30b9\u306b\u554f\u984c\u304c\u3042\u308a\u307e\u3059'
cfrSessionTerminated = u'\u30bb\u30c3\u30b7\u30e7\u30f3\u7d42\u4e86'
cfrSoundIOError = u'\u97f3\u58f0\u51fa\u5165\u529b\u30a8\u30e9\u30fc'
cfrSoundRecordingError = u'\u97f3\u58f0\u9332\u97f3\u30a8\u30e9\u30fc'
cfrUnknown = u'\u4e0d\u660e'
cfrUserDoesNotExist = u'\u30e6\u30fc\u30b6\u30fb\u96fb\u8a71\u756a\u53f7\u304c\u5b58\u5728\u3057\u307e\u305b\u3093'
cfrUserIsOffline = u'\u30aa\u30d5\u30e9\u30a4\u30f3\u3067\u3059'
chsAllCalls = u'\u30ec\u30ac\u30b7\u30fc\u30c0\u30a4\u30a2\u30ed\u30b0'
chsDialog = u'\u30c0\u30a4\u30a2\u30ed\u30b0'
chsIncomingCalls = u'\u8907\u6570\u53d7\u4fe1\u8a31\u53ef\u5f85\u3061\u3042\u308a'
chsLegacyDialog = u'\u30ec\u30ac\u30b7\u30fc\u30c0\u30a4\u30a2\u30ed\u30b0'
chsMissedCalls = u'\u30c0\u30a4\u30a2\u30ed\u30b0'
chsMultiNeedAccept = u'\u8907\u6570\u53d7\u4fe1\u8a31\u53ef\u5f85\u3061\u3042\u308a'
chsMultiSubscribed = u'\u8907\u6570\u5951\u7d04\u3042\u308a'
chsOutgoingCalls = u'\u8907\u6570\u5951\u7d04\u3042\u308a'
chsUnknown = u'\u4e0d\u660e'
chsUnsubscribed = u'\u5951\u7d04\u306a\u3057'
clsBusy = u'\u53d6\u308a\u8fbc\u307f\u4e2d'
clsCancelled = u'\u30ad\u30e3\u30f3\u30bb\u30eb\u3055\u308c\u307e\u3057\u305f'
clsEarlyMedia = u'\u65e9\u671f\u30e1\u30c7\u30a3\u30a2\u518d\u751f\u4e2d'
clsFailed = u'\u901a\u8a71\u63a5\u7d9a\u306b\u5931\u6557\u3057\u307e\u3057\u305f\u3002'
clsFinished = u'\u7d42\u4e86'
clsInProgress = u'\u901a\u8a71\u4e2d'
clsLocalHold = u'\u81ea\u8eab\u306b\u3088\u308b\u4e00\u6642\u505c\u6b62\u4e2d'
clsMissed = u'\u4ef6\u306e\u4e0d\u5728\u7740\u4fe1'
clsOnHold = u'\u4fdd\u7559\u4e2d'
clsRefused = u'\u62d2\u5426\u3055\u308c\u307e\u3057\u305f'
clsRemoteHold = u'\u76f8\u624b\u304c'
clsRinging = u'\u901a\u8a71\u4e2d'
clsRouting = u'\u30eb\u30fc\u30c6\u30a3\u30f3\u30b0\u4e2d'
clsTransferred = u'\u4e0d\u660e'
clsTransferring = u'\u4e0d\u660e'
clsUnknown = u'\u4e0d\u660e'
clsUnplaced = u'\u901a\u8a71\u306f\u767a\u4fe1\u3055\u308c\u307e\u305b\u3093\u3067\u3057\u305f'
clsVoicemailBufferingGreeting = u'\u5fdc\u7b54\u30e1\u30c3\u30bb\u30fc\u30b8\u306e\u30d0\u30c3\u30d5\u30a1\u4e2d'
clsVoicemailCancelled = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u304c\u30ad\u30e3\u30f3\u30bb\u30eb\u3055\u308c\u307e\u3057\u305f'
clsVoicemailFailed = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u9001\u4fe1\u5931\u6557'
clsVoicemailPlayingGreeting = u'\u5fdc\u7b54\u30e1\u30c3\u30bb\u30fc\u30b8\u306e\u518d\u751f\u4e2d'
clsVoicemailRecording = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u3092\u9332\u97f3\u4e2d'
clsVoicemailSent = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u304c\u9001\u4fe1\u3055\u308c\u307e\u3057\u305f'
clsVoicemailUploading = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u306e\u30a2\u30c3\u30d7\u30ed\u30fc\u30c9\u4e2d'
cltIncomingP2P = u'P2P\u901a\u8a71\u7740\u4fe1'
cltIncomingPSTN = u'\u96fb\u8a71\u7740\u4fe1'
cltOutgoingP2P = u'P2P\u901a\u8a71\u9001\u4fe1'
cltOutgoingPSTN = u'\u96fb\u8a71\u9001\u4fe1'
cltUnknown = u'\u4e0d\u660e'
cmeAddedMembers = u'\u30e1\u30f3\u30d0\u30fc\u3092\u8ffd\u52a0\u3057\u307e\u3057\u305f'
cmeCreatedChatWith = u'\u30c1\u30e3\u30c3\u30c8\u3092\u4f5c\u6210\uff1a'
cmeEmoted = u'\u4e0d\u660e'
cmeLeft = u'\u6b8b\u3057\u307e\u3057\u305f'
cmeSaid = u'\u8a00\u3044\u307e\u3057\u305f'
cmeSawMembers = u'\u30e1\u30f3\u30d0\u30fc\u3092\u8868\u793a\u3057\u307e\u3057\u305f'
cmeSetTopic = u'\u30bf\u30a4\u30c8\u30eb\u3092\u8868\u793a'
cmeUnknown = u'\u4e0d\u660e'
cmsRead = u'\u65e2\u8aad'
cmsReceived = u'\u53d7\u4fe1\u5b8c\u4e86'
cmsSending = u'\u9001\u4fe1\u4e2d...'
cmsSent = u'\u9001\u4fe1\u6e08'
cmsUnknown = u'\u4e0d\u660e'
conConnecting = u'\u63a5\u7d9a\u4e2d'
conOffline = u'\u30aa\u30d5\u30e9\u30a4\u30f3'
conOnline = u'\u30aa\u30f3\u30e9\u30a4\u30f3'
conPausing = u'\u4e00\u6642\u505c\u6b62\u4e2d'
conUnknown = u'\u4e0d\u660e'
cusAway = u'\u4e00\u6642\u9000\u5e2d\u4e2d'
cusDoNotDisturb = u'\u53d6\u308a\u8fbc\u307f\u4e2d'
cusInvisible = u'\u30ed\u30b0\u30a4\u30f3\u72b6\u614b\u3092\u96a0\u3059'
cusLoggedOut = u'\u30aa\u30d5\u30e9\u30a4\u30f3'
cusNotAvailable = u'\u7121\u52b9'
cusOffline = u'\u30aa\u30d5\u30e9\u30a4\u30f3'
cusOnline = u'\u30aa\u30f3\u30e9\u30a4\u30f3'
cusSkypeMe = u'Skype Me'
cusUnknown = u'\u4e0d\u660e'
cvsBothEnabled = u'\u30d3\u30c7\u30aa\u9001\u53d7\u4fe1'
cvsNone = u'\u30d3\u30c7\u30aa\u306a\u3057'
cvsReceiveEnabled = u'\u30d3\u30c7\u30aa\u53d7\u4fe1'
cvsSendEnabled = u'\u30d3\u30c7\u30aa\u9001\u4fe1'
cvsUnknown = u''
grpAllFriends = u'\u3059\u3079\u3066\u306e\u53cb\u4eba'
grpAllUsers = u'\u3059\u3079\u3066\u306e\u30e6\u30fc\u30b6'
grpCustomGroup = u'\u30aa\u30ea\u30b8\u30ca\u30eb'
grpOnlineFriends = u'\u30aa\u30f3\u30e9\u30a4\u30f3\u30d5\u30ec\u30f3\u30ba'
grpPendingAuthorizationFriends = u'\u8a8d\u8a3c\u5f85\u3061'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'\u6700\u8fd1\u30b3\u30f3\u30bf\u30af\u30c8\u3057\u305f\u30e6\u30fc\u30b6'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype\u30d5\u30ec\u30f3\u30ba'
grpSkypeOutFriends = u'SkypeOut\u30d5\u30ec\u30f3\u30ba'
grpUngroupedFriends = u'\u30b0\u30eb\u30fc\u30d7\u306b\u5165\u3063\u3066\u3044\u306a\u3044\u30b3\u30f3\u30bf\u30af\u30c8'
grpUnknown = u'\u4e0d\u660e'
grpUsersAuthorizedByMe = u'\u8a8d\u8a3c\u3057\u305f\u30b0\u30eb\u30fc\u30d7'
grpUsersBlockedByMe = u'\u30d6\u30ed\u30c3\u30af\u3057\u305f\u30b0\u30eb\u30fc\u30d7'
grpUsersWaitingMyAuthorization = u'\u8a8d\u8a3c\u5f85\u3061'
leaAddDeclined = u'\u8ffd\u52a0\u62d2\u5426'
leaAddedNotAuthorized = u'\u8ffd\u52a0\u8005\u306f\u8a8d\u8a3c\u3055\u308c\u3066\u3044\u308b\u5fc5\u8981\u304c\u3042\u308a\u307e\u3059'
leaAdderNotFriend = u'\u8ffd\u52a0\u8005\u306f\u53cb\u4eba\u306e\u5fc5\u8981\u304c\u3042\u308a\u307e\u3059'
leaUnknown = u'\u4e0d\u660e'
leaUnsubscribe = u'\u5951\u7d04\u306a\u3057'
leaUserIncapable = u'\u30e6\u30fc\u30b6'
leaUserNotFound = u'\u30e6\u30fc\u30b6\u304c\u898b\u3064\u304b\u308a\u307e\u305b\u3093'
olsAway = u'\u4e00\u6642\u9000\u5e2d\u4e2d'
olsDoNotDisturb = u'\u53d6\u308a\u8fbc\u307f\u4e2d'
olsNotAvailable = u'\u7121\u52b9'
olsOffline = u'\u30aa\u30d5\u30e9\u30a4\u30f3'
olsOnline = u'\u30aa\u30f3\u30e9\u30a4\u30f3'
olsSkypeMe = u'Skype Me'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'\u4e0d\u660e'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'\u5973\u6027'
usexMale = u'\u7537\u6027'
usexUnknown = u'\u4e0d\u660e'
vmrConnectError = u'\u63a5\u7d9a\u30a8\u30e9\u30fc'
vmrFileReadError = u'\u30d5\u30a1\u30a4\u30eb\u8aad\u307f\u8fbc\u307f\u30a8\u30e9\u30fc'
vmrFileWriteError = u'\u30d5\u30a1\u30a4\u30eb\u66f8\u304d\u8fbc\u307f\u30a8\u30e9\u30fc'
vmrMiscError = u'\u305d\u306e\u4ed6\u30a8\u30e9\u30fc'
vmrNoError = u'\u30a8\u30e9\u30fc\u306a\u3057'
vmrNoPrivilege = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u5951\u7d04\u306a\u3057'
vmrNoVoicemail = u'\u8a72\u5f53\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u304c\u898b\u3064\u304b\u308a\u307e\u305b\u3093'
vmrPlaybackError = u'\u518d\u751f\u30a8\u30e9\u30fc'
vmrRecordingError = u'\u9332\u97f3\u30a8\u30e9\u30fc'
vmrUnknown = u'\u4e0d\u660e'
vmsBlank = u'\u7a7a\u6b04'
vmsBuffering = u'\u30d0\u30c3\u30d5\u30a1\u4e2d'
vmsDeleting = u'\u524a\u9664\u4e2d'
vmsDownloading = u'\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9\u4e2d'
vmsFailed = u'\u5931\u6557'
vmsNotDownloaded = u'\u672a\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9'
vmsPlayed = u'\u518d\u751f\u6e08'
vmsPlaying = u'\u518d\u751f\u4e2d'
vmsRecorded = u'\u9332\u97f3\u5b8c\u4e86'
vmsRecording = u'\u30dc\u30a4\u30b9\u30e1\u30fc\u30eb\u3092\u9332\u97f3\u4e2d'
vmsUnknown = u'\u4e0d\u660e'
vmsUnplayed = u'\u672a\u518d\u751f'
vmsUploaded = u'\u30a2\u30c3\u30d7\u30ed\u30fc\u30c9\u5b8c\u4e86'
vmsUploading = u'\u30a2\u30c3\u30d7\u30ed\u30fc\u30c9\u4e2d'
vmtCustomGreeting = u'\u30aa\u30ea\u30b8\u30ca\u30eb\u5fdc\u7b54\u30e1\u30c3\u30bb\u30fc\u30b8'
vmtDefaultGreeting = u'\u6a19\u6e96\u5fdc\u7b54\u30e1\u30c3\u30bb\u30fc\u30b8'
vmtIncoming = u'voicemail\u3092\u7740\u4fe1\u3057\u305f\u6642'
vmtOutgoing = u'\u9001\u4fe1'
vmtUnknown = u'\u4e0d\u660e'
vssAvailable = u'\u5229\u7528\u53ef\u80fd'
vssNotAvailable = u'\u7121\u52b9'
vssPaused = u'\u4e00\u6642\u505c\u6b62\u4e2d'
vssRejected = u'\u62d2\u5426\u3055\u308c\u307e\u3057\u305f'
vssRunning = u'\u518d\u751f\u4e2d'
vssStarting = u'\u8d77\u52d5\u4e2d'
vssStopping = u'\u505c\u6b62\u4e2d'
vssUnknown = u'\u4e0d\u660e'



apiAttachAvailable = u'API verf\xfcgbar'
apiAttachNotAvailable = u'Nicht verf\xfcgbar'
apiAttachPendingAuthorization = u'Ausstehende Genehmigungsanfrage'
apiAttachRefused = u'Abgelehnt'
apiAttachSuccess = u'Erfolg'
apiAttachUnknown = u'Unbekannt'
budDeletedFriend = u'Aus Freundesliste gel\xf6scht'
budFriend = u'Freund'
budNeverBeenFriend = u'War noch nie in Freundesliste'
budPendingAuthorization = u'Ausstehende Genehmigungsanfrage'
budUnknown = u'Unbekannt'
cfrBlockedByRecipient = u'Anruf von Empf\xe4nger gesperrt'
cfrMiscError = u'Sonstiger Fehler'
cfrNoCommonCodec = u'Kein Standard-Codec'
cfrNoProxyFound = u'Kein Proxy gefunden'
cfrNotAuthorizedByRecipient = u'Aktueller Benutzer nicht von Empf\xe4nger genehmigt'
cfrRecipientNotFriend = u'Empf\xe4nger kein Freund'
cfrRemoteDeviceError = u'Problem mit dem Audioger\xe4t der Gegenstelle'
cfrSessionTerminated = u'Sitzung beendet'
cfrSoundIOError = u'Ton-E/A-Fehler'
cfrSoundRecordingError = u'Aufnahmefehler'
cfrUnknown = u'Unbekannt'
cfrUserDoesNotExist = u'Benutzer/Telefonnummer gibt es nicht'
cfrUserIsOffline = u'Sie oder er ist offline'
chsAllCalls = u'Dialog mit Altversion'
chsDialog = u'Dialog'
chsIncomingCalls = u'Mehrere m\xfcssen annehmen'
chsLegacyDialog = u'Dialog mit Altversion'
chsMissedCalls = u'Dialog'
chsMultiNeedAccept = u'Mehrere m\xfcssen annehmen'
chsMultiSubscribed = u'Mehrere abonniert'
chsOutgoingCalls = u'Mehrere abonniert'
chsUnknown = u'Unbekannt'
chsUnsubscribed = u'Abonnement gek\xfcndigt'
clsBusy = u'Besetzt'
clsCancelled = u'Abbrechen'
clsEarlyMedia = u'Wiedergabe von Early Media'
clsFailed = u'Anruf leider fehlgeschlagen!'
clsFinished = u'Beendet'
clsInProgress = u'Aktives Gespr\xe4ch'
clsLocalHold = u'In lokaler Wartestellung'
clsMissed = u'Anruf in Abwesenheit von:'
clsOnHold = u'Konferenz wird gehalten'
clsRefused = u'Abgelehnt'
clsRemoteHold = u'In Fern-Wartestellung'
clsRinging = u'Gespr\xe4che'
clsRouting = u'Wird weitergeleitet'
clsTransferred = u'Unbekannt'
clsTransferring = u'Unbekannt'
clsUnknown = u'Unbekannt'
clsUnplaced = u'Nie get\xe4tigt'
clsVoicemailBufferingGreeting = u'Ansage wird gepuffert'
clsVoicemailCancelled = u'Voicemail wurde abgebrochen'
clsVoicemailFailed = u'Fehler bei Sprachnachricht'
clsVoicemailPlayingGreeting = u'Ansage wird abgespielt'
clsVoicemailRecording = u'Sprachnachricht wird aufgezeichnet'
clsVoicemailSent = u'Voicemail wurde gesendet'
clsVoicemailUploading = u'Voicemail wird hochgeladen'
cltIncomingP2P = u'Eingehender P2P-Anruf'
cltIncomingPSTN = u'Eingehender Anruf'
cltOutgoingP2P = u'Ausgehender P2P-Anruf'
cltOutgoingPSTN = u'Ausgehender Anruf'
cltUnknown = u'Unbekannt'
cmeAddedMembers = u'Hinzugef\xfcgte Mitglieder'
cmeCreatedChatWith = u'Chat erstellt mit'
cmeEmoted = u'Unbekannt'
cmeLeft = u'Links'
cmeSaid = u'Gesagt'
cmeSawMembers = u'Gesehene Mitglieder'
cmeSetTopic = u'Thema festlegen'
cmeUnknown = u'Unbekannt'
cmsRead = u'Gelesen'
cmsReceived = u'Empfangen'
cmsSending = u'Sende...'
cmsSent = u'Gesendet'
cmsUnknown = u'Unbekannt'
conConnecting = u'Verbindungsaufbau'
conOffline = u'Offline'
conOnline = u'Online'
conPausing = u'Wird angehalten'
conUnknown = u'Unbekannt'
cusAway = u'Abwesend'
cusDoNotDisturb = u'Besch\xe4ftigt'
cusInvisible = u'Als offline anzeigen'
cusLoggedOut = u'Offline'
cusNotAvailable = u'Nicht verf\xfcgbar'
cusOffline = u'Offline'
cusOnline = u'Online'
cusSkypeMe = u'Skype Me-Modus'
cusUnknown = u'Unbekannt'
cvsBothEnabled = u'Video wird gesendet und empfangen'
cvsNone = u'Kein Video'
cvsReceiveEnabled = u'Video wird empfangen'
cvsSendEnabled = u'Video wird gesendet'
cvsUnknown = u''
grpAllFriends = u'Alle Freunde'
grpAllUsers = u'Alle Benutzer'
grpCustomGroup = u'Benutzerdefiniert'
grpOnlineFriends = u'Online-Freunde'
grpPendingAuthorizationFriends = u'Ausstehende Genehmigungsanfrage'
grpProposedSharedGroup = u'Proposed Shared Group'
grpRecentlyContactedUsers = u'K\xfcrzlich kontaktierte Benutzer'
grpSharedGroup = u'Shared Group'
grpSkypeFriends = u'Skype-Freunde'
grpSkypeOutFriends = u'SkypeOut-Freunde'
grpUngroupedFriends = u'Nicht gruppierte Freunde'
grpUnknown = u'Unbekannt'
grpUsersAuthorizedByMe = u'Von mir genehmigt'
grpUsersBlockedByMe = u'Von mir blockiert'
grpUsersWaitingMyAuthorization = u'Warten auf meine Genehmigung'
leaAddDeclined = u'Hinzuf\xfcgung abgelehnt'
leaAddedNotAuthorized = u'Hinzugef\xfcgter Benutzer muss genehmigt sein'
leaAdderNotFriend = u'Hinzuf\xfcgender Benutzer muss Freund sein'
leaUnknown = u'Unbekannt'
leaUnsubscribe = u'Abonnement gek\xfcndigt'
leaUserIncapable = u'Benutzer unf\xe4hig'
leaUserNotFound = u'Kein Benutzer gefunden'
olsAway = u'Abwesend'
olsDoNotDisturb = u'Besch\xe4ftigt'
olsNotAvailable = u'Nicht verf\xfcgbar'
olsOffline = u'Offline'
olsOnline = u'Online'
olsSkypeMe = u'Skype Me-Modus'
olsSkypeOut = u'SkypeOut'
olsUnknown = u'Unbekannt'
smsMessageStatusComposing = u'Composing'
smsMessageStatusDelivered = u'Delivered'
smsMessageStatusFailed = u'Failed'
smsMessageStatusRead = u'Read'
smsMessageStatusReceived = u'Received'
smsMessageStatusSendingToServer = u'Sending to Server'
smsMessageStatusSentToServer = u'Sent to Server'
smsMessageStatusSomeTargetsFailed = u'Some Targets Failed'
smsMessageStatusUnknown = u'Unknown'
smsMessageTypeCCRequest = u'Confirmation Code Request'
smsMessageTypeCCSubmit = u'Confirmation Code Submit'
smsMessageTypeIncoming = u'Incoming'
smsMessageTypeOutgoing = u'Outgoing'
smsMessageTypeUnknown = u'Unknown'
smsTargetStatusAcceptable = u'Acceptable'
smsTargetStatusAnalyzing = u'Analyzing'
smsTargetStatusDeliveryFailed = u'Delivery Failed'
smsTargetStatusDeliveryPending = u'Delivery Pending'
smsTargetStatusDeliverySuccessful = u'Delivery Successful'
smsTargetStatusNotRoutable = u'Not Routable'
smsTargetStatusUndefined = u'Undefined'
smsTargetStatusUnknown = u'Unknown'
usexFemale = u'Weiblich'
usexMale = u'M\xe4nnlich'
usexUnknown = u'Unbekannt'
vmrConnectError = u'Verbindungsfehler'
vmrFileReadError = u'Fehler beim Lesen der Datei'
vmrFileWriteError = u'Fehler beim Schreiben in die Datei'
vmrMiscError = u'Sonstiger Fehler'
vmrNoError = u'Kein Fehler'
vmrNoPrivilege = u'Keine Voicemail-Berechtigung'
vmrNoVoicemail = u'Voicemail gibt es nicht'
vmrPlaybackError = u'Fehler bei der Wiedergabe'
vmrRecordingError = u'Fehler bei der Aufnahme'
vmrUnknown = u'Unbekannt'
vmsBlank = u'Leer'
vmsBuffering = u'Pufferung'
vmsDeleting = u'Wird gel\xf6scht'
vmsDownloading = u'Download l\xe4uft'
vmsFailed = u'Fehlgeschlagen'
vmsNotDownloaded = u'Nicht gedownloadet'
vmsPlayed = u'Abgespielt'
vmsPlaying = u'Wiedergabe'
vmsRecorded = u'Aufgenommen'
vmsRecording = u'Sprachnachricht wird aufgezeichnet'
vmsUnknown = u'Unbekannt'
vmsUnplayed = u'Nicht abgespielt'
vmsUploaded = u'Upload beendet'
vmsUploading = u'Upload'
vmtCustomGreeting = u'Benutzerdefinierte Ansage'
vmtDefaultGreeting = u'Standardansage'
vmtIncoming = u'Ich eine Sprachnachricht empfange'
vmtOutgoing = u'Ausgehend'
vmtUnknown = u'Unbekannt'
vssAvailable = u'Verf\xfcgbar'
vssNotAvailable = u'Nicht verf\xfcgbar'
vssPaused = u'Angehalten'
vssRejected = u'Abgelehnt'
vssRunning = u'Wird ausgef\xfchrt'
vssStarting = u'Wird gestartet'
vssStopping = u'Wird gestoppt'
vssUnknown = u'Unbekannt'
